define(function(require) {
    var $ = require('jquery');
    /*
     * Lazy Load - jQuery plugin for lazy loading images
     *
     * Copyright (c) 2007-2012 Mika Tuupola
     *
     * Licensed under the MIT license:
     *   http://www.opensource.org/licenses/mit-license.php
     *
     * Project home:
     *   http://www.appelsiini.net/projects/lazyload
     *
     * Version:  1.7.2
     *
     */
    $window = $(window);
    gc.$elements = $('img[data-original]');
    var objMap = {}, imgIndex = 0;
    // 显示图片回调
    gc.loadImage = loadImage;
    gc.loadImageError = loadImageError;
    // 显示图片回调
    function loadImage(strUrl, index) {
        var $this, $parent;
        $this = objMap[index]['dom'];
        $parent = $this.parent();
        $this[0].loaded = true;
        settings.beforeLoad && settings.beforeLoad.call($this[0]);
        // 部分浏览器可能不缓存图片
        $this.bind('error', function() {
            loadImageError(index);
        });
        if (window.KalaGame) {
            $this.attr("src", strUrl);
        } else {
            $this.hide().attr("src", strUrl);
            $this[settings.effect](settings.effect_speed);
        }
        // 攻略图片, 去除图片高度
        if ($this[0].style.width === '100%') {
            $this.height('');
        }
        /* Remove image from array so it is not looped next time. */
        var temp = $.grep(gc.$elements, function(element) {
            return !element.loaded;
        });
        gc.$elements = $(temp);
        settings.afterLoad && settings.afterLoad.call($this[0]);
        if ($parent.hasClass('imgloading')) {
            //$this.parent().removeClass("imgloading");
            $parent.find('b').remove();
            $parent.attr("class", "");
        }
        localStorage.setItem('img-' + strUrl, 1);
    };
    // 加载图片失败回调
    function loadImageError(index) {
        var $this, $parent, $loading, obj;
        obj = objMap[index];
        $this = obj['dom'];
        $parent = $this.parent();
        $loading = $parent.find('b');
        // 有默认图片则显示默认背景
        if (obj['src']) {
            $this.attr('src', './style/img/noimgbg.png');
        }
        // 图片加载失败，则去掉加载中的样式
        if ($loading.length) {
            $loading.remove();
        }
        $parent.removeClass("imgloading");
    }

    /* Check if something appears when window is resized. */
    $window.bind("resize", function(event) {
        $.updateLazyload();
    });
    /* Cache container as jQuery as object. */
    var $container = null;
    var settings = {
        threshold      : 0,
        failure_limit  : 1,
        effect         : "fadeIn",
        effect_speed   : 500,
        skip_invisible : true
    };
    $.updateLazyload = function() {
        if (!gc.$elements || !gc.$elements.length) {
            return false;
        }
        var counter = 0;
        gc.$elements.each(function() {
            var $this = $(this);
            if (settings.skip_invisible && !$this.is(":visible")) {
                return;
            }
            $container = $this.parents('[data-container]');
            if ($.abovethetop(this, settings) || $.leftofbegin(this, settings)) {
                /* Nothing. */
            } else if (!$.belowthefold(this, settings) && !$.rightoffold(this, settings)) {
                $this.trigger("appear");
            } else if (++counter > settings.failure_limit) {
                return false;
            }
        });
        return true;
    };
    $.fn.lazyload = function(options) {
        gc.$elements = gc.$elements ? gc.$elements.add(this) : $(this);
        var settings = {
            effect       : window.KalaGame ? "show" : "fadeIn",
            effect_speed : window.KalaGame ? 0 : 500,
            beforeLoad   : null,
            afterLoad    : null
        };
        if (options) {
            $.extend(settings, options);
        }
        //如果是2g网络，则不显示大图
        var net = navigator.network;
        var is2G = net && net.connection && net.connection.type == Connection.CELL_2G;
        var is3G = net && net.connection && net.connection.type == Connection.CELL_3G;
        var is4G = net && net.connection && net.connection.type == Connection.CELL_4G;
        var strNoImageMode = localStorage.getItem('noImageMode');
        if (typeof strNoImageMode != "string") {
            strNoImageMode = "1";
        }
        var isNoImageMode = (strNoImageMode === "1") && (is2G || is3G || is4G);
        var strLoad = isNoImageMode ? 'wait_insetimg_2G' : 'wait_insetimg';
        var $loading = '<b class="loadingIcon"></b>';
        this.each(function() {
            var $this = $(this);
            var $parent = $this.parent();
            var original = $this.attr('data-original');
            var strLoading = $this.attr('data-loading') || '';
            // 如果图片已缓存，则直接显示
            var isCached = localStorage.getItem('img-' + original);
            if (isCached) {
                $this.attr('src', original);
                return true;
            }
            objMap[imgIndex] = {
                'dom' : $this,
                'src' : $this.attr('src')
            };
            // 增加图片的背景
            if (!$this.attr('src') && !$parent.hasClass(strLoad)) {
                $parent = $("<span class='" + strLoad + " " + strLoading + "'></span>");
                $this.after($parent);
                $parent.append($this);
                var width = $this.width();
                var height = $this.height();
                if (width && height) {
                    $parent.width(width);
                    $parent.height(height);
                }
                // 2g网络点击显示图片
                if (isNoImageMode) {
                    $parent.one(gc.click, function() {
                        if (!$parent.hasClass(strLoad) || $parent.hasClass('imgloading')) {
                            return;
                        }
                        var idx = $('img[data-original]').index($this);
                        bindAppearEvent($this, idx);
                        $this.trigger("appear");
                        //阻止冒泡
                        return false;
                    });
                    imgIndex++;
                    return true;
                }
            } else {
                // 有默认加载背景，需设置图片宽高
                $this.one('load', function() {
                    var width = $this.width();
                    var height = $this.height();
                    if (width && height) {
                        $this.width(width);
                        $this.height(height);
                    }
                });
            }
            bindAppearEvent($this, imgIndex++);
        });
        function bindAppearEvent($this, i) {
            /* When appear is triggered load original image. */
            $this.one("appear", function() {
                //if ($this[0].loaded) { return; }
                var $parent = $this.parent();
                var original = $this.attr('data-original');
                //判断图片是否有src，如果没有则需要加imgloading样式
                if (!$this.attr('src') && $parent.hasClass(strLoad)) {
                    $parent.prepend($loading);
                    $parent.addClass("imgloading");
                }
                var isHttpImg = original && /http:\/\//.test(original);
                if (isHttpImg && window.KLCommon && KLCommon.loadImage) {
                    KLCommon.loadImage(original, function(fileUrl) {
                        loadImage(fileUrl, i);
                    }, function() {
                        loadImageError(i);
                    });
                } else {
                    $("<img />").bind("load",function() {
                        loadImage(original, i);
                    }).bind('error',function() {
                        loadImageError(i);
                    }).attr("src", original);
                }
            });
        }

        /* Force initial check if images should appear. */
        $.updateLazyload();
        return this;
    };
    /* Convenience methods in jQuery namespace.           */
    /* Use as  $.belowthefold(element, {threshold : 100, container : window}) */
    $.belowthefold = function(element, settings) {
        var fold;
        if (!$container || !$container.length) {
            fold = $window.height() + $window.scrollTop();
        } else {
            fold = $container.offset().top + $container.height();
        }
        return fold <= $(element).offset().top - settings.threshold;
    };
    $.rightoffold = function(element, settings) {
        var fold;
        if (!$container || !$container.length) {
            fold = $window.width() + $window.scrollLeft();
        } else {
            fold = $container.offset().left + $container.width();
        }
        return fold <= $(element).offset().left - settings.threshold;
    };
    $.abovethetop = function(element, settings) {
        var fold;
        if (!$container || !$container.length) {
            fold = $window.scrollTop();
        } else {
            fold = $container.offset().top;
        }
        return fold >= $(element).offset().top + settings.threshold + $(element).height();
    };
    $.leftofbegin = function(element, settings) {
        var fold;
        if (!$container || !$container.length) {
            fold = $window.scrollLeft();
        } else {
            fold = $container.offset().left;
        }
        return fold >= $(element).offset().left + settings.threshold + $(element).width();
    };
    $.inviewport = function(element, settings) {
        return !$.rightofscreen(element, settings) && !$.leftofscreen(element, settings) && !$.belowthefold(element, settings) && !$.abovethetop(element, settings);
    };
}); 