define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), com = require('gameComm'), lazyload = require('lazyload');
    exports.init = init;
    exports.onStop = onStop;
    exports.updateTime = updateTime;
    // 列表默认的显示数目
    var defaultCount = 10 * lib.listCountMultiples();
    var currentReply, serverTime, lastPostId, userId, temp_replyId = null, isShowNewReply = false;
    var uploadImages = [];
    var M = {
        newReplyReminder    : {
            _count : 0,
            _timer : null,
            show   : function() {
                var count = M.newReplyReminder._count;
                var $reminder = $('#reply_reminder');
                if (count) {
                    $reminder.find('span').html(count);
                    $reminder.show();
                } else {
                    $reminder.hide();
                }
            },
            fetch  : function() {
                // 每30秒取一次
                var duration = 30000;
                M.newReplyReminder._timer = lib.setTimeout(M.getNewReplyList, duration);
            }
        },
        getPostDetail       : function() {
            var url = lib.bbsUrl + 'forum/getPostDetail';
            var params = {
                appId   : lib.getParam('gameId'),
                postId  : lib.getParam('postId'),
                boardId : lib.getParam('boardId')
            };
            var hasShowPostDetail = false;
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showPostDetail(response);
                    if (!hasShowPostDetail) {
                        hasShowPostDetail = true;
                        // 获取帖子列表
                        M.getReplyList(0);
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, {
                cache     : true,
                noLoading : true
            });
        },
        // getReplyList : function(start, $more, replyId) {
        getReplyList        : function(start, replyId) {
            var url = lib.bbsUrl + 'forum/getPostReplyList';
            var params = {
                appId    : lib.getParam('gameId'),
                postId   : lib.getParam('postId'),
                boardId  : lib.getParam('boardId'), // 部落版块
                start    : start,
                count    : defaultCount,
                subCount : 1000
            }
            // 添加倒序浏览参数
            var isReverse = lib.getSessionItem('isReverse');
            console.log('=============================isReverse: ' + isReverse + '***' + typeof isReverse)
            if (isReverse) {
                params['isReverse'] = isReverse;
                if (isShowNewReply) {
                    params['start'] = 0;
                }
            }
            //            if (window.KalaGameUi && ( typeof isReverse === 'number') && !start) {
            //                lib.showLoading();
            //            }
            if (replyId) {
                params.parentId = replyId;
            }
            lib.postCrossList(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    // 倒序显示时，记录当前总的回复数
                    if (isReverse) {
                        if (isShowNewReply || (start == 0)) {
                            $('#reply_list').attr('totalCount', response.totalCount);
                        }
                    }
                    V.showPostReplyList(response, start);
                    // 定时检查是否有新回复
                    if (isReverse || !response.hasMore) {
                        M.newReplyReminder.fetch();
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, function() {
                // M.getReplyList(start, $more, replyId);
                M.getReplyList(start, replyId);
            }, false);
        },
        getNewReplyList     : function() {
            var page = lib.getParam('page');
            if (page != 'game-bbscontent') {
                return;
            }
            var url = lib.bbsUrl + 'forum/getPostReplyList';
            var params = {
                appId    : lib.getParam('gameId'),
                postId   : lib.getParam('postId'),
                boardId  : lib.getParam('boardId'), // 部落版块
                start    : $('#reply_list li').length,
                count    : defaultCount,
                subCount : 1000
            }
            // 添加倒序浏览参数
            var isReverse = lib.getSessionItem('isReverse');
            if (isReverse) {
                params['isReverse'] = isReverse;
                // 倒序显示时，使用当前总的回复数
                var strTotalCount = $('#reply_list').attr('totalCount');
                if (strTotalCount) {
                    var nCount = parseInt(strTotalCount) + $('[latestItem]').length;
                    params['start'] = nCount;
                }
            }
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    var hasMore = response.hasMore;
                    $('#spinner_list').attr('hasMore', hasMore);
                    if (isReverse || !hasMore) {
                        // 定时检查是否有新回复
                        M.newReplyReminder.fetch();
                        var responseLength = response.list.length;
                        var newReplyCount = hasMore ? responseLength + '+' : responseLength;
                        M.newReplyReminder._count = newReplyCount;
                        M.newReplyReminder.show();
                    }
                }
            }, {
                noLoading : true
            });
        },
        submitReply         : function() {
            var $btn = $('#btn_reply');
            var btnDisabled = $btn.hasClass('ontimer');
            if (!btnDisabled) {
                var params = {};
                var $image = $('#uploadImage').find('input');
                if (!$image.length) {
                    params = lib.getFormData('#createReply');
                    if (!params) {
                        return;
                    }
                } else {
                    params.content = $('#reply_content').val();
                }
                var url = lib.bbsUrl + 'forum/replyPost';
                params.appId = lib.getParam('gameId');
                params.postId = lib.getParam('postId');
                params.boardId = lib.getParam('boardId');
                $btn.addClass('ontimer');
                //回复的回复没有发图功能，所以不需要调用android的代码
                if (window.KalaGame && KalaGame.createReply) {
                    // 添加图片，token，uid信息
                    lib.getDefaultData(params);
                    params.images = uploadImages;
                    var str_params = JSON.stringify(params);
                    console.log("createReply:" + str_params);
                    KalaGame.createReply(str_params);
                } else {
                    lib.postCrossIframe(url, params, '#createReply', 'createReplyFrame');
                }
            }
        },
        submitReplyReply    : function($btn, replyId) {
            var btnDisabled = $btn.hasClass('ontimer');
            if (!btnDisabled) {
                var $content = $btn.parent().find('[contentId]');
                var content = $.trim($content.val());
                if (!content) {
                    lib.showTip('请输入回复内容！');
                    return;
                }
                var url = lib.bbsUrl + 'forum/replyPost';
                var params = {
                    appId    : lib.getParam('gameId'),
                    postId   : lib.getParam('postId'),
                    boardId  : lib.getParam('boardId'),
                    parentId : replyId,
                    content  : content
                };
                $btn.addClass('ontimer');
                lib.postCross(url, params, function(response) {
                    $btn.removeClass('ontimer');
                    if (response.result == 1) {
                        V.showLatestReplyReply(response, $btn);
                    } else {
                        if (response.ret == -6001) {
                            lib.showVcode(function() {
                                M.submitReplyReply($btn, replyId);
                            });
                        }
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            }
        },
        getUserId           : function() {
            var url = lib.userUrl + 'detail/getAccountInfo';
            lib.postCross(url, function(response) {
                if (response.result == 1) {
                    userId = response.data.userId;
                    gc.userId = userId;
                }
            }, {
                cache : true
            });
        },
        retrievePermission  : function() {
            var url = lib.bbsUrl + 'forum/checkPermission';
            var params = {
                appId : lib.getParam('gameId')
            }
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    var $replyList = $('#reply_list');
                    // 解绑longTap事件
                    $replyList.off(gc.longTap, 'li div[replyId], [hasMoreReply] dl');
                    // 重新绑定帖子设置事件
                    if (response.valid) {
                        // 回复列表
                        $replyList.on(gc.longTap, 'li div[replyId]', function() {
                            var $reply = $(this);
                            $reply.attr('userType', 'admin');
                            C.bindCtrMenuEvent($reply);
                        });
                        // 回复的回复列表
                        $replyList.on(gc.longTap, '[hasMoreReply] dl', function() {
                            var $reply = $(this);
                            $reply.attr('userType', 'admin');
                            C.bindCtrMenuEvent($reply, true);
                            return false;
                        });
                    } else {
                        // 回复列表
                        $replyList.on(gc.longTap, 'li div[replyId]', function() {
                            var $reply = $(this);
                            var postAuthor = $reply.attr('author');
                            if (userId != postAuthor) {
                                if (window.KalaGame) {
                                    lib.showTip('对不起，您没有权限！');
                                }
                                return;
                            }
                            $reply.attr('userType', 'ordinary_user');
                            C.bindCtrMenuEvent($reply);
                        });
                        // 回复的回复列表
                        $replyList.on(gc.longTap, '[hasMoreReply] dl', function() {
                            var $reply = $(this);
                            var postAuthor = $reply.attr('author');
                            if (userId != postAuthor) {
                                if (window.KalaGame) {
                                    lib.showTip('对不起，您没有权限！');
                                }
                                return;
                            }
                            $reply.attr('userType', 'ordinary_user');
                            C.bindCtrMenuEvent($reply, true);
                            return false;
                        });
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, {
                cache     : true,
                noLoading : true
            });
        },
        deleteReply         : function() {
            lib.confirm("确定要删除该条回复？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/deleteReply';
                var replyInfo = lib.getSessionItem('replyInfo');
                params = (replyInfo && JSON.parse(replyInfo)) || {};
                // 去除无用参数
                delete params.forbiddenUserId;
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        if (currentReply) {
                            var btnRR = $(currentReply).find('span.btn_ctrl').attr('btnRR');
                            if (!btnRR) {
                                V.updatePostReplyCount(true);
                                currentReply.remove();
                            } else {
                                var $parent = $(currentReply).parentsUntil('#reply_list').last();
                                var replyId = $parent.attr('replyId');
                                V.setNewReplyCount(replyId, true);
                                currentReply.remove();
                                var $wrap = $parent.find('[hasMoreReply]');
                                if (!$wrap.find('dl').length) {
                                    $wrap.addClass('invisible');
                                }
                            }
                            lib.showTip('操作成功！');
                        }
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        muteUser            : function() {
            lib.confirm("确定要禁言该用户？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/forbiddenUser';
                var replyInfo = lib.getSessionItem('replyInfo');
                params = {
                    appId           : lib.getParam('gameId'),
                    forbiddenUserId : (replyInfo && JSON.parse(replyInfo)).forbiddenUserId
                };
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        currentReply && currentReply.attr('forbidden', 1);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        unMuteUser          : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要取消该用户的禁言？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/cancelForbiddenUser';
                var replyInfo = lib.getSessionItem('replyInfo');
                params = {
                    appId           : lib.getParam('gameId'),
                    forbiddenUserId : (replyInfo && JSON.parse(replyInfo)).forbiddenUserId
                };
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        currentReply && currentReply.attr('forbidden', 0);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        formatData          : function(data) {
            if (!data) {
                return;
            }
            // 设置头像
            var icon = data.icon;
            data.icon = icon ? icon : gc.defaultIcon_96;
            var createTime = data.createTime;
            if (createTime) {
                data.postTime = lib.dateDiff(serverTime, data.createTime);
            } else {
                data.postTime = '加载中...';
            }
            // 解析表情
            var postCount = data.content;
            var pattern = /\[[\u4e00-\u9fa5]+\]/ig;
            if (postCount) {
                data.content = postCount.replace(pattern, com.parseEmotionPath);
            }
            // 解析图片
            var attach = data.attach;
            if (attach) {
                var html = com.parseUploadedImages(postCount, attach);
                data.content += html;
            }
            // 设置是否加V
            var isAuthenticated = data.authenticated;
            data.addV = '';
            if (isAuthenticated == '1') {
                data.addV = 'admin';
            }
            return data;
        },
        formatDataList      : function(dataList, replyReply) {
            var len = dataList.length;
            if (!len) {
                return;
            }
            // 匹配表情
            var pattern = /\[[\u4e00-\u9fa5]+\]/ig;
            for (var i = 0; i < len; i++) {
                var reply = dataList[i];
                if (replyReply) {
                    reply.replyTag = lib.getSessionItem('lz') == reply.author ? '楼主' : '';
                }
                var html = V.generateReplyTag(reply.replyTag);
                reply.replyTags = html ? html : '';
                reply.replyTime = lib.dateDiff(serverTime, reply.createTime);
                // 设置禁言标识
                if (!reply.forbidden) {
                    reply.forbidden = 0;
                } else {
                    reply.forbidden = 1;
                }
                // 设置默认用户头像
                if (!reply.icon) {
                    reply.icon = gc.defaultIcon_96;
                }
                // 设置楼层信息
                if (!replyReply) {
                    // 楼层样式
                    reply.floorStyle = '';
                    if (reply.floor == 2) {
                        reply.floor = '沙发';
                        reply.floorStyle = 'sofa';
                    } else if (reply.floor == 3) {
                        reply.floor = '板凳';
                    } else if (reply.floor == 4) {
                        reply.floor = '地板';
                    } else if (reply.floor == 5) {
                        reply.floor = '下水道';
                    } else {
                        reply.floor += '楼';
                    }
                    // 楼中楼
                    var replyData = reply.replyData;
                    var replyHtml = M.generateRereplyList(replyData);
                    reply.replyList = replyHtml;
                    reply.replyListClass = replyHtml ? '' : 'invisible';
                    reply.hasMoreReply = replyData ? replyData.hasMore : false;
                    if (replyData) {
                        reply.hasMoreReply = replyData.hasMore;
                        reply.loadMoreClass = replyData.hasMore ? '' : 'invisible';
                    } else {
                        reply.hasMoreReply = false;
                        reply.loadMoreClass = 'invisible';
                    }
                }
                // 解析表情
                var replyContent = reply.content;
                if (replyContent) {
                    reply.content = replyContent.replace(pattern, com.parseEmotionPath);
                }
                // 解析图片
                var attach = reply.attach;
                if (attach) {
                    var contentHtml = com.parseUploadedImages(replyContent, attach);
                    reply.content += contentHtml;
                }
                // 设置是否加V
                var isAuthenticated = reply.authenticated;
                reply.addV = '';
                if (isAuthenticated == '1') {
                    reply.addV = 'admin';
                }
            }
            return dataList;
        },
        loadMore            : function() {
            $('#reply_reminder').hide();
            var $replyList = $('#reply_list');
            var start = $replyList.find('li').not('[latestItem]').length;
            M.getReplyList(start);
        },
        generateRereplyList : function(data) {
            var html = '';
            if (data && data.list) {
                var dataList = M.formatDataList(data.list, true);
                html = lib.template2(dataList, '#rereply_list_template');
            }
            return html;
        }
    };
    var V = {
        showPostDetail       : function(response) {
            var data = M.formatData(response.data);
            lib.template(data, '#post_content');
            var $html = $('#post_content');
            var $li = $('#post_content').find('li');
            // 设置加V样式
            $li.find('[name="nickName"]').addClass(data.addV);
            $('#game_bbscontent').show();
            // 设置回复中图片的尺寸
            lib.setImgSize($html.find('[name="content"]'));
            // 设置信息
            $li.attr('author', data.author);
            $li.attr('replies', data.replies);
            $li.attr('createTime', data.createTime);
            $li.find('img[name="icon"]').attr('userId', data.author);
            // 更新回复数
            V.updatePostViewCount(data);
            // 图片渐显
            $('#post_content').find('img[data-original]').lazyload();
        },
        showPostReplyList    : function(response, start) {
            // 设置禁言以及默认头像
            M.formatDataList(response.list);
            // 如为页面初始化，则清空html
            !start && $('#reply_list').html('');
            // 显示缓存数据
            var objOptions = {};
            var isReverse = lib.getSessionItem('isReverse');
            if (isReverse) {
                objOptions['isReverse'] = isReverse;
                objOptions['isShowNewReply'] = isShowNewReply;
                isShowNewReply = false;
            }
            var $html = lib.showCacheList2(response, '#reply_list_template', '#reply_list', objOptions);
            // 绑定延迟加载图片事件
            if ($html) {
                lib.setImgSize($html.find('p.comment'));
                $html.find('img').lazyload();
            }
            // 倒序显示结束后，隐藏loading及清除缓存数据
            if (window.KalaGameUi) {
                // 隐藏加载中
                lib.hideLoading();
            }
        },
        showLatestReply      : function(response) {
            // 帖子数据 - 添加楼层信息、设置是否楼主
            var data = response.data;
            serverTime = response.serverTime;
            // 楼主
            data.replyTag = lib.getSessionItem('lz') == data.author ? '楼主' : '';
            var dataList = M.formatDataList([data]);
            var $html = $(lib.template2(dataList, '#reply_list_template'));
            $html.attr('latestItem', 'true');
            var isReverse = lib.getSessionItem('isReverse');
            if (isReverse) {
                var $replyList = $('#reply_list > li');
                if ($replyList.length) {
                    $html.insertBefore($replyList.first());
                } else {
                    $('#reply_list').html($html);
                }
            } else {
                $html.appendTo('#reply_list');
            }
            // 设置回复中图片的尺寸
            lib.setImgSize($html.find('p.comment'));
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
            // 更新回复数
            V.updatePostReplyCount();
        },
        showLatestReplyReply : function(response, $btn) {
            var $wrap = $btn.parentsUntil('#reply_list').last().find('[hasMoreReply]');
            var $rBox = $wrap.find('.bbs_replybtnbox');
            var replyId = $btn.attr('replyId');
            // 清空并隐藏回复框
            var $replyBox = $btn.parent();
            $btn.removeClass('hover');
            $replyBox.addClass('invisible');
            $replyBox.find('[contentId]').val('');
            com.updateHeight($replyBox.find('[contentId]'));
            // 帖子数据 - 设置是否楼主
            var data = response.data;
            // 楼主
            data.replyTag = lib.getSessionItem('lz') == data.author ? '楼主' : '';
            var dataList = M.formatDataList([data], true);
            var $html = $(lib.template2(dataList, '#rereply_list_template'));
            $html.attr('latestItem', 'true');
            $html.insertBefore($rBox);
            $wrap.removeClass('invisible');
            // 设置回复中图片的尺寸
            lib.setImgSize($html.find('p.comment'));
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
            // 设置回复数
            V.setNewReplyCount(replyId);
            lib.showTip('回复成功！');
        },
        generateReplyTag     : function(tag) {
            // tag不存在，不作处理
            if (!tag) {
                return;
            }
            var tagClass = '', tagName = '', data = {};
            if (tag == '楼主') {
                data = [
                    {
                        tagClass : 'lz',
                        tagName  : tag
                    }
                ];
            }
            return lib.template2(data, '#reply_tag_template');
        },
        updatePostReplyCount : function(removeReply) {
            var newPostInfo = JSON.parse(lib.getSessionItem('newPostInfo'));
            if (newPostInfo) {
                // 更新回复数
                if (removeReply) {
                    newPostInfo.replies = parseInt(newPostInfo.replies) - 1;
                } else {
                    newPostInfo.replies = parseInt(newPostInfo.replies) + 1;
                    // 在帖子列表页面，帖子需要改变位置
                    newPostInfo['__setPos'] = true;
                    newPostInfo['serverTime'] = serverTime;
                }
                lib.setSessionItem('newPostInfo', JSON.stringify(newPostInfo));
            }
        },
        updatePostViewCount  : function(data) {
            if (!data) {
                return;
            }
            // 保存回复信息
            var newPostInfo = {
                views   : ++data.views,
                replies : data.replies,
                postId  : data.postId
            };
            lib.setSessionItem('newPostInfo', JSON.stringify(newPostInfo));
        },
        setNewReplyCount     : function(replyId, removeReply) {
            var $reply = $('#reply_list').find('li[replyId="' + replyId + '"]');
            var $span = $reply.find('span.datainfo_replies');
            var content = $.trim($span.html());
            var count = parseInt(content);
            if (!isNaN(count)) {
                if (removeReply) {
                    count = (count - 1) < 0 ? 0 : (count - 1);
                } else {
                    count = count + 1;
                }
                $span.html(count);
            }
        },
        readURL              : function(evt) {
            var allowedTypes = ['image/gif', 'image/jpeg', 'image/png'];
            var val = this.value;
            var files = evt.target.files;
            if (files && files[0]) {
                var file_type = files[0].type;
                if (allowedTypes.indexOf(file_type) == -1) {
                    alert('文件格式错误！');
                    return;
                } else if (file_type == allowedTypes[0]) {
                    $('#btn_photo_library').addClass('nobg');
                } else {
                    $('#btn_photo_library').removeClass('nobg');
                }
                var reader = new FileReader();
                reader.readAsDataURL(files[0]);
                reader.onload = function(e) {
                    V.preImage(e.target.result);
                };
            }
        },
        clearStored          : function(clearImage) {
            uploadImages = [];
            // 清除file和内容
            var $btn = $('#btn_photo_library');
            $btn.removeClass("showdel nobg");
            $btn.html('<input type="file" />');
            $('#uploadImage').find('input').remove();
            !clearImage && $('#reply_content').val('');
        },
        preImage             : function(icon) {
            uploadImages = [];
            // 保存上传的图片的实际地址
            uploadImages.push(icon);
            var $img = $('<img />');
            var $btn = $('#btn_photo_library');
            //增加显示删除按钮
            $btn.addClass("showdel");
            // 图片路径
            $img.attr('src', icon);
            // 清空之前选择的图片
            $btn.find('img').remove();
            $img.appendTo($btn);
            var $uploadImage = $('#uploadImage');
            $uploadImage.find('input').remove();
            $btn.find('input').attr('name', 'image1').appendTo($uploadImage);
            $input = $('<input type="file" />');
            $input.appendTo($btn);
        },
        showCtrMenu          : function($this) {
            var forbidden = parseInt($this.attr('forbidden'));
            var $ctrbtn = $this.find('span.btn_ctrl');
            var ordinary = ($this.attr('userType') == 'admin') ? false : true;
            // 设置菜单显示内容及事件回调
            var option = {};
            option['title'] = '选择操作';
            // 设置不同用户菜单的显示
            if (ordinary) {
                option['data'] = [
                    {
                        text : '删除',
                        name : 3
                    }
                ];
            } else {
                // 设置禁言用户和非禁言用户菜单的显示
                if (forbidden) {
                    option['data'] = [
                        {
                            text : '删除',
                            name : 3
                        },
                        {
                            text : '取消禁言',
                            name : 5
                        }
                    ];
                } else {
                    option['data'] = [
                        {
                            text : '删除',
                            name : 3
                        },
                        {
                            text : '禁言',
                            name : 4
                        }
                    ];
                }
            }
            option['callback'] = function(name) {
                switch (name) {
                    case 3:
                        M.deleteReply();
                        break;
                    case 4:
                        M.muteUser();
                        break;
                    case 5:
                        M.unMuteUser();
                        break;
                    default:
                        $('#_menu').hide();
                        break;
                }
            };
            if (window.KalaGameUi && KalaGameUi.showSelectDialog) {
                KalaGameUi.showSelectDialog(option);
            } else {
                lib.showOptMenu(option);
            }
        },
        'changeReminderPos'  : function() {
            var $reminder = $('#reply_reminder');
            var isReverse = lib.getSessionItem('isReverse');
            if (isReverse) {
                $reminder.insertBefore('#reply_list');
            } else {
                $reminder.insertAfter('#reply_list');
            }
            // 倒序是提示android更新倒序状态
            if (window.KalaGameUi && KalaGameUi.updateBbsOrder) {
                KalaGameUi.updateBbsOrder(isReverse);
            }
        }
    };
    var C = {
        init                       : function() {
            M.getUserId();
            // 绑定回复设置事件
            M.retrievePermission();
            C.bindShowOriginalImageEvent();
            C.bindToggleReplyBoxEvent();
            // 绑定显示用户信息事件
            lib.bindShowUserInfoEvent('#reply_list, #post_content');
            // 绑定插入图片事件
            C.bindUploadImageEvent();
            C.bindShowEmotionEvent();
            C.bindCtrMenuVisibilityEvent();
            C.bindReplyEvent();
            C.bindAutoHeightEvent("#createReply, #game_bbscontent");
            if (window.KalaGameUi && KalaGameUi.showReplyBtn) {
                C.bindHideReply();
                $('#game_bbscontent').css("padding-bottom", "0px");
            } else {
                $('#createReply').show();
            }
        },
        bindAutoHeightEvent        : function(selector) {
            if (lib.getParam("channel") != "apple") {
                var $shadom = $('<textarea type="text" style="position: absolute; border-width: 0px; padding: 0px; visibility: hidden;"></textarea>');
                $(selector).on("input", "textarea", function() {
                    com.updateHeight($(this));
                });
            }
        },
        bindHideReply              : function() {
            var oldBodyHeight = $(window).height();
            // 高度有时获取不对
            setTimeout(function() {
                oldBodyHeight = $(window).height();
            }, 300);
            var handler = 0;
            console.log("oldBodyHeight:" + oldBodyHeight);
            $("#game_bbscontent").on("click", "textarea",function() {
                var $li = $(this).parents('li');
                lib.setTimeout(function() {
                    C.updateScroll($li, true);
                    //清除定时器
                    handler && clearInterval(handler);
                    handler = lib.setInterval(function() {
                        var newHeight = $(window).height();
                        //console.log("newHeight:" + newHeight + ", oldBodyHeight:" + oldBodyHeight);
                        if (newHeight >= oldBodyHeight) {
                            showReplyBtn();
                        } else {
                            hideReplyBtn();
                        }
                    }, 400);
                }, 700);
                hideReplyBtn();
            }).on("blur", "textarea", showReplyBtn);
            function hideReplyBtn() {
                if (window.KalaGameUi && KalaGameUi.hideReplyBtn) {
                    KalaGameUi.hideReplyBtn();
                    $("#game_bbscontent").css("padding-bottom", "100px");
                } else {
                    $("#createReply").hide();
                    $("#game_bbscontent").css("padding-bottom", "200px");
                }
            }

            function showReplyBtn() {
                if (window.KalaGameUi && KalaGameUi.showReplyBtn) {
                    KalaGameUi.showReplyBtn();
                    $("#game_bbscontent").css("padding-bottom", "0px");
                } else {
                    $("#createReply").show();
                    $("#game_bbscontent").css("padding-bottom", "92px");
                }
                clearInterval(handler);
                handler = 0;
            }
        },
        updateScroll               : function($li, forceScroll) {
            var replyTop = $li.offset().top;
            var replyHeight = $li.outerHeight(true);
            var bottomBarHeight = $('.gamebbs_btnbox:visible').outerHeight(true);
            var scrollHeight = replyTop + replyHeight + bottomBarHeight - window.innerHeight;
            var scrollTop = document.body.scrollTop;
            if (scrollHeight > 0 && ((scrollHeight > scrollTop) || forceScroll)) {
                $('body').animate({
                    'scrollTop' : scrollHeight
                });
            }
        },
        bindReplyEvent             : function() {
            // 绑定回复回帖事件
            $('#btn_reply').on(gc.click, M.submitReply);
            $('#reply_list').on(gc.click, '.btn_bbs_send', function() {
                var $this = $(this);
                var replyId = $this.attr('replyId');
                $('#emotion_wrap').addClass('invisible');
                M.submitReplyReply($this, replyId);
            });
            // 提取新回复
            $('#reply_reminder').on(gc.click, function() {
                $('#reply_reminder').hide();
                // 设置提取新消息标识
                isShowNewReply = true;
                var $replyList = $('#reply_list');
                var start = $replyList.find('li').not('[latestItem]').length;
                var isReverse = lib.getSessionItem('isReverse');
                if (isReverse) {
                    start = $replyList.attr('totalCount');
                }
                M.getReplyList(start);
            });
            // 加载更多回帖回复
            // $('#reply_list').on(gc.click, 'p.more', function() {
            // var $this = $(this);
            // var start = $this.parent().find('dl').length;
            // var replyId = $this.attr('replyId');
            // M.getReplyList(start, $this, replyId);
            // });
        },
        bindCtrMenuVisibilityEvent : function() {
            // 管理菜单事件
            if (!window.KalaGame) {
                $('#reply_list').on(gc.click, 'span.btn_ctrl', function() {
                    var $this = $(this);
                    var btnRR = $this.attr('btnRR');
                    var $parents = $this.parentsUntil('#reply_list');
                    if (btnRR == 'true') {
                        $parents = $this.parentsUntil('[hasMoreReply]');
                        currentReply = $parents.last();
                        V.showCtrMenu(currentReply, true);
                    } else {
                        currentReply = $parents.last();
                        V.showCtrMenu(currentReply);
                    }
                    return false;
                });
            }
        },
        bindCtrMenuEvent           : function($this, btnRR) {
            var $ctrbtn = btnRR ? $this.find('span.btn_ctrl') : $this.find('span.btn_ctrl').not('[btnRR]');
            var ordinary = ($this.attr('userType') == 'admin') ? false : true;
            var $parents = btnRR ? $this.parentsUntil('[hasMoreReply]') : $this.parentsUntil('#reply_list');
            // 客户端保存当前回复
            var postAuthor = $this.attr('author');
            var hasPermission = !ordinary || (userId == postAuthor);
            if (window.KalaGame) {
                currentReply = $parents.last();
                hasPermission && V.showCtrMenu($this);
            } else {
                if (event.type == 'mouseout') {
                    $ctrbtn.hide();
                } else {
                    hasPermission && $ctrbtn.show();
                }
            }
            // 缓存数据
            var replyInfo = {
                appId           : lib.getParam('gameId'),
                postId          : lib.getParam('postId'),
                boardId         : lib.getParam('boardId'),
                replyId         : $this.attr('replyId'),
                forbiddenUserId : $this.attr('author')
            };
            // 回复的回复添加parentId
            if (btnRR) {
                replyInfo.parentId = $this.parentsUntil('#reply_list').last().attr('replyId');
            }
            lib.setSessionItem('replyInfo', JSON.stringify(replyInfo));
        },
        bindShowOriginalImageEvent : function() {
            $('#reply_list, #post_content').on(gc.click, '.comment img[data-original]', function() {
                var $this = $(this);
                var $content = $this.parent();
                // 设置当前点击图片的索引
                var index = $content.find('img[data-original]').index($this);
                lib.showOriginalImg($content, index);
                // 阻止事件冒泡
                return false;
            });
        },
        bindToggleReplyBoxEvent    : function() {
            $('#reply_list').on(gc.click, 'li div[replyId], li [hasMoreReply] dl', function() {
                var $this = $(this);
                var $reply = $this.parentsUntil('#reply_list').last();
                var replyId = $reply.attr('replyId');
                // 关闭打开的回复框
                var $parent = $this.parent();
                var $replies = $('#reply_list').find('li');
                var $replyBox = $parent.find('.bbs_replybtnbox');
                // 关闭其它打开的回复框
                $replies.each(function() {
                    var $li = $(this);
                    var $dls = $li.find('dl');
                    var $box = $li.find('.bbs_replybtnbox');
                    var $replyList = $li.find('[hasMoreReply]');
                    if ($li.attr('replyId') == replyId) {
                        $box.toggleClass('invisible');
                        // 回复的回复为空时的处理逻辑
                        !$dls.length && $replyList.toggleClass('invisible');
                    } else {
                        $box.addClass('invisible');
                        // 回复的回复为空时的处理逻辑
                        !$dls.length && $replyList.addClass('invisible');
                    }
                });
                // 设置回复的回复输入框的位置
                var visibility = $replyBox.hasClass('invisible');
                if (!visibility) {
                    C.updateScroll($reply, false);
                    // 穿透问题，可能会选中输入框
                    $reply.find("textarea").attr('disabled', 'disabled');
                    setTimeout(function() {
                        $reply.find("textarea").removeAttr('disabled');
                    }, 300);
                }
                $('#emotion_wrap').addClass('invisible');
            });
        },
        bindShowEmotionEvent       : function() {
            $('#reply_list').on(gc.click, 'span[rel]', function() {
                var $this = $(this);
                var replyId = $this.attr('replyId');
                var redirectPage = $this.attr('rel');
                if (replyId) {
                    temp_replyId = replyId;
                }
                com.showEmotions(temp_replyId);
            });
        },
        bindUploadImageEvent       : function() {
            if (!window.KalaGame) {
                $('#createReply').on('change', 'input[type="file"]', V.readURL);
            }
            $('#btn_photo_library').on(gc.click, function() {
                // $('#add_pic input').focus().trigger(gc.click);
                if (uploadImages.length) {
                    lib.confirm("确定要删除图片吗？", function(index) {
                        if (index == 1) {
                            V.clearStored(true);
                        }
                    });
                } else if (navigator.camera) {
                    // 本地的上传方法
                    var type = "PHOTOLIBRARY";
                    // 或者CAMERA
                    C.uploadNativePhoto(type);
                }
            });
        },
        uploadNativePhoto          : function() {
            window.KalaGame.getPicture(onSuccess, onFail, false);
            function onSuccess(imageUri) {
                console.log("onSuccess, imageUri:" + imageUri);
                V.preImage(imageUri);
            }

            function onFail(message) {
                console.log("onFail, message:" + message);
            }
        }
    }
    // 初始化一次
    C.init();
    function init() {
        // 重置为正序浏览
        V.changeReminderPos();
        // 显示回复按钮
        if (window.KalaGameUi && KalaGameUi.showReplyBtn) {
            KalaGameUi.showReplyBtn();
        }
        // 相同游戏ID使用缓存数据
        var postId = lib.getParam('postId');
        if (postId != lastPostId) {
            $('#emotion_wrap').addClass('invisible');
            $('#reply_list').html('');
            // 显示loading
            $('#spinner_list').show();
            $('#loadingText').css('visibility', 'visible');
            // 获取帖子详细信息
            M.getPostDetail();
            lastPostId = postId;
        } else {
            var response = lib.getSessionItem('latestReply');
            if (response) {
                response = JSON.parse(response);
                response && V.showLatestReply(response);
                lib.removeSessionItem('latestReply');
            }
            // 定时检查是否有新回复
            var hasMore = $('#reply_list').attr('hasMore') == 'true' ? true : false;
            var isReverse = lib.getSessionItem('isReverse');
            if (isReverse || !hasMore) {
                M.newReplyReminder.fetch();
            }
        }
        // 绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#reply_list'));
        // postMessage回调
        gc.msgCallback = function(response) {
            $('#btn_reply').removeClass('ontimer');
            if (response.result == 1) {
                // 回复成功清除内容
                V.clearStored();
                V.showLatestReply(response);
                lib.showTip('回复成功！');
            } else {
                if (response.ret == -6001) {
                    lib.showVcode(M.submitReply);
                }
                // 失败，显示提示信息
                lib.showTip(response.msg);
            }
        };
        // 浏览顺序回调
        gc.reverseReplies = function(nReverse) {
            lib.setSessionItem('isReverse', nReverse);
            // 修改消息提示位置
            V.changeReminderPos();
            M.getReplyList(0);
        };
    }

    function updateTime(serverTime) {
        var $replyList = $('#reply_list li div span[createTime], #post_content li div span[createTime], #reply_list dl span[createTime]');
        $replyList.each(function() {
            var $this = $(this);
            var createTime = $this.attr('createTime');
            if (serverTime && createTime) {
                var replyTime = lib.dateDiff(serverTime, createTime);
                $this.html(replyTime);
            }
        });
    }

    function onStop() {
        lib.clearTimer();
        console.log('=======leaving page: ' + lib.getParam('page') + ' & stop timer=======');
    }
});
