define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload'), slider = require('slider');
    exports.init = init;
    exports.onStop = onStop;
    exports.updateTime = updateTime;
    // 列表默认的显示数目
    var defaultCount = 10 * lib.listCountMultiples();
    var currentPost, serverTime, gameId, userId;
    var M = {
        getUserId                 : function() {
            var url = lib.userUrl + 'detail/getBaseInfo';
            lib.postCross(url, function(response) {
                if (response.result == 1) {
                    userId = response.data.userId;
                    gc.userId = userId;
                    // 如果用户没有上传头像，则显示提示
                    var icons = response.data.icons;
                    var $slider = $('#slider_avatar');
                    if ((!icons || !icons.length) && lib.getParam('channel') != "apple") {
                        var strIsInit = $slider.attr('isInit');
                        if (strIsInit !== 'true') {
                            var $images = $slider.find('img');
                            $images.each(function() {
                                var $this = $(this);
                                var strSrc = './style/' + gc.theme + $this.attr('src');
                                $this.attr('src', strSrc);
                            });
                            $slider.attr('isInit', true);
                        }
                        $slider.show();
                        // 有时广告位宽度不对
                        setTimeout(function() {
                            C.initSlider();
                        }, 100);
                    } else {
                        $slider.hide();
                    }
                }
            }, {
                cache     : true,
                noLoading : true
            });
        },
        getGameInfo               : function() {
            var url = lib.gameUrl + 'app/getAppInfo';
            var params = {
                appId : lib.getParam('gameId')
            };
            lib.postCross(url, params, function(objResult) {
                if (objResult.result == 1) {
                    lib.setTitle(objResult.appName + "部落");
                }
            }, {
                cache     : "must",
                noLoading : true
            });
        },
        newPostReminder           : {
            _count    : 0,
            _stickIds : [],
            _postIds  : [],
            _timer    : null,
            show      : function() {
                var count = M.newPostReminder._count;
                var $reminder = $('#post_reminder');
                if (count) {
                    $reminder.find('span').html(count);
                    $reminder.show();
                } else {
                    $reminder.hide();
                }
            },
            fetch     : function() {
                // 每30秒取一次
                var duration = 30000;
                M.newPostReminder._timer = lib.setTimeout(M.getNewPostList, duration);
            }
        },
        getPostList               : function(start, isPullToRefresh) {
            var url = lib.bbsUrl + 'forum/getPostList';
            var params = {
                appId : lib.getParam('gameId'),
                start : start || 0,
                count : defaultCount
            }
            lib.postCrossList(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showPostList(response, start);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
                // 客户端关闭刷新
                if (isPullToRefresh && window.KalaGameUi && KalaGameUi.closeRefresh) {
                    KalaGameUi.closeRefresh();
                }
            }, function() {
                M.getPostList(start);
            }, false);
        },
        getNewPostList            : function() {
            var page = lib.getParam('page');
            if (page != 'game-bbslist') {
                return;
            }
            var url = lib.bbsUrl + 'forum/checkNewPost';
            var params = M.generateNewPostListParams();
            console.log("getNewPostList");
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    var responseData = response.data;
                    var postsCount = responseData.postIds.length + responseData.stickIds.length;
                    M.newPostReminder.fetch();
                    M.newPostReminder._count = postsCount;
                    M.newPostReminder._stickIds = responseData.stickIds;
                    M.newPostReminder._postIds = responseData.postIds;
                    M.newPostReminder.show();
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, {
                noLoading : true
            });
        },
        retrievePermission        : function() {
            var url = lib.bbsUrl + 'forum/checkPermission';
            var params = {
                appId : lib.getParam('gameId')
            };
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    var $postList = $('#post_list');
                    // 解绑longTap事件
                    $postList.off(gc.longTap, 'li');
                    // 重新绑定帖子设置事件
                    if (response.valid) {
                        $postList.on(gc.longTap, 'li', function() {
                            var $this = $(this);
                            $this.attr('userType', 'admin');
                            C.bindCtrMenuEvent($this);
                        });
                    } else {
                        $postList.on(gc.longTap, 'li', function() {
                            var $this = $(this);
                            var postAuthor = $this.attr('author');
                            if (userId != postAuthor) {
                                if (window.KalaGame) {
                                    lib.showTip('对不起，您没有权限！');
                                }
                                return;
                            }
                            $this.attr('userType', 'ordinary_user');
                            C.bindCtrMenuEvent($this);
                        });
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, {
                cache     : true,
                noLoading : true
            });
        },
        retrieveNewMsgCount       : function() {
            if (!window.KalaGameUi) {
                return;
            }
            var strUrl = lib.bbsUrl + 'forum/getNewMessagesCount';
            // 客户端不添加appId信息，默认获取全部信息
            var objData = {};
            if (lib.getParam('channel') !== 'client') {
                objData.appId = lib.getParam('gameId');
            }
            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    // 设置数量提示
                    var nCount = objResult.data.count;
                    var strCount = nCount;
                    if (nCount > 99) {
                        strCount = '...';
                    }
                    strCount = '' + strCount;
                    KalaGameUi.updateNewMsgCount && KalaGameUi.updateNewMsgCount(strCount);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
                // 默认一秒拉取一次回复数
                var nFrequency = objResult.frequency && parseInt(objResult.frequency);
                if (!nFrequency || nFrequency < 0) {
                    nFrequency = 1;
                }
                lib.setTimeout(M.retrieveNewMsgCount, nFrequency * 1000);
            }, {
                noLoading : true
            });
        },
        stickPost                 : function() {
            var url = lib.bbsUrl + 'forum/stickPost';
            var postInfo = lib.getSessionItem('postInfo');
            params = (postInfo && JSON.parse(postInfo)) || {};
            // 去除无用参数
            delete params.forbiddenUserId;
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    V.refreshPostList();
                    lib.showTip('操作成功！');
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            });
        },
        unstickPost               : function() {
            var url = lib.bbsUrl + 'forum/unstickPost';
            var postInfo = lib.getSessionItem('postInfo');
            params = (postInfo && JSON.parse(postInfo)) || {};
            // 去除无用参数
            delete params.forbiddenUserId;
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    V.refreshPostList(true);
                    lib.showTip('操作成功！');
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            });
        },
        deletePost                : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要删除该贴？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/deletePost';
                var postInfo = lib.getSessionItem('postInfo');
                params = (postInfo && JSON.parse(postInfo)) || {};
                // 去除无用参数
                delete params.forbiddenUserId;
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        currentPost && currentPost.remove();
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        muteUser                  : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要禁言该用户？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/forbiddenUser';
                var postInfo = lib.getSessionItem('postInfo');
                params = {
                    appId           : lib.getParam('gameId'),
                    forbiddenUserId : (postInfo && JSON.parse(postInfo)).forbiddenUserId
                };
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        currentPost && currentPost.attr('forbidden', 1);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        unMuteUser                : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要取消该用户的禁言？", function(index) {
                if (index != 1) {
                    return;
                }
                var url = lib.bbsUrl + 'forum/cancelForbiddenUser';
                var postInfo = lib.getSessionItem('postInfo');
                params = {
                    appId           : lib.getParam('gameId'),
                    forbiddenUserId : (postInfo && JSON.parse(postInfo)).forbiddenUserId
                };
                lib.postCross(url, params, function(response) {
                    if (response.result == 1) {
                        currentPost && currentPost.attr('forbidden', 0);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(response.msg);
                    }
                });
            });
        },
        generateNewPostListParams : function() {
            var params = {};
            var $postList = $('#post_list li');
            var postCount = $postList.length;
            var stickCount = $postList.find('span.top').length;
            var $stickList = $postList.slice(0, stickCount);
            // 游戏ID
            params.appId = lib.getParam('gameId');
            // 版块ID
            params.boardId = $postList.first().attr('boardId');
            // 当前页面最新的普通贴时间
            params.lastestPostTime = $postList.eq(stickCount).attr('lastupdatetime');
            // 当前页面最新的置顶帖时间
            params.lastestStickTime = $stickList.first().attr('lastupdatetime');
            // 当前页面的所有帖子ID
            var postIds = [];
            for (var i = 0; i < postCount; i++) {
                postIds.push($($postList[i]).attr('postId'));
            }
            params.existIds = postIds.join();
            return params;
        },
        formatDataList            : function(dataList, newPost) {
            var len = dataList.length;
            if (!len) {
                return;
            }
            // 去除重复帖子, 只对获取新帖时进行
            if (newPost) {
                var postList = [], key = 'postId';
                $('#post_list li').each(function() {
                    postList[$(this).attr(key)] = 1;
                });
                dataList = lib.removeDuplicated(postList, dataList, key);
                len = dataList.length;
            }
            for (var i = 0; i < len; i++) {
                var post = dataList[i];
                var html = V.generatePostTag(post.type);
                post.postTags = html ? html : '';
                post.postTime = lib.dateDiff(serverTime, post.lastUpdateTime);
                // 修改默认用户头像
                var icon = post.icon;
                if (!icon) {
                    post.icon = gc.defaultIcon_96;
                }
                if (!post.forbidden) {
                    post.forbidden = 0;
                } else {
                    post.forbidden = 1;
                }
                // 设置是否加V
                var isAuthenticated = post.authenticated;
                post.addV = '';
                if (isAuthenticated == '1') {
                    post.addV = 'admin';
                }
            }
            return dataList;
        },
        loadMore                  : function() {
            var $postList = $('#post_list');
            var start = $postList.find('li').length;
            M.getPostList(start);
        },
        loadNewPosts              : function() {
            $('#post_reminder').hide();
            var url = lib.bbsUrl + 'forum/getPostListByIds';
            var stickIds = M.newPostReminder._stickIds;
            var postIds = M.newPostReminder._postIds;
            var boardId = $('#post_list li').first().attr('boardId');
            var params = {
                appId   : lib.getParam('gameId'),
                postIds : stickIds.concat(postIds).join()
            }
            if (boardId) {
                params.boardId = boardId;
            }
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    var stickPostCount = stickIds.length;
                    V.showNewPosts(response, stickPostCount);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            });
        }
    };
    var V = {
        showPostList    : function(response, start) {
            var $spinner = $('#spinner_list');
            var $postList = $('#post_list');
            var $noreplies = $('#noreplies');
            // 页面初始化时的操作
            !start && $postList.html('');
            // 格式化数据
            var dataList = M.formatDataList(response.list);
            if (dataList && dataList.length) {
                $noreplies.hide();
                // 显示缓存数据
                var $html = lib.showCacheList2(response, '#post_list_template', $postList);
                $postList.show();
                // 绑定延迟加载图片事件
                $html && $html.find('img').lazyload();
            } else {
                $postList.hide();
                $noreplies.show();
                $spinner.hide();
            }
        },
        showNewPosts    : function(response, stickPostCount) {
            var $postList = $('#post_list li');
            var stickCount = $postList.find('span.top').length;
            var $plainList = $postList.slice(stickCount);
            // 帖子数据
            var dataList = M.formatDataList(response.data.list, true);
            var stickList = dataList.slice(0, stickPostCount);
            var postList = dataList.slice(stickPostCount);
            // 生成普通帖
            if (postList.length) {
                var $html = $(lib.template2(postList, '#post_list_template'));
                $html.insertBefore($plainList.first());
                // 绑定延迟加载图片事件
                $html && $html.find('img').lazyload();
            }
            // 生成置顶帖
            if (stickList.length) {
                var $html = $(lib.template2(stickList, '#post_list_template'));
                $html.insertBefore($postList.first());
                // 绑定延迟加载图片事件
                $html && $html.find('img').lazyload();
            }
        },
        refreshPostList : function(refresh) {
            if (refresh) {
                M.getPostList();
            } else {
                if (!currentPost) {
                    return;
                }
                // 把帖子类型设置为置顶帖
                var stick = 11;
                var $posts = $('#post_list li');
                var index = $posts.index(currentPost);
                // 生成置顶的标签
                var html = V.generatePostTag(stick);
                if (!index) {
                    var $firstPost = $posts.first();
                    // 设置帖子类型标识
                    $firstPost.attr('type', stick);
                    var $subject = $firstPost.find('.comment_title');
                    var subject = $subject.html();
                    $subject.html(html + subject);
                } else {
                    $(currentPost).attr('type', stick);
                    var $firstPost = $posts.first();
                    var $subject = $(currentPost).find('.comment_title');
                    var subject = $subject.html();
                    $subject.html(html + subject);
                    $(currentPost).insertBefore($firstPost);
                }
            }
        },
        showLatestPost  : function(response) {
            response = JSON.parse(response);
            serverTime = response.serverTime;
            var $list = $('#post_list');
            var $postList = $list.find('li');
            var $noreplies = $('#noreplies');
            var stickCount = $postList.find('span.top').length;
            var $plainList = $postList.slice(stickCount);
            // 帖子数据
            var dataList = M.formatDataList([response.data], true);
            var $html = $(lib.template2(dataList, '#post_list_template'));
            if ($postList.length) {
                $html.insertBefore($plainList.first());
            } else {
                $list.html($html);
            }
            // 显示列表，隐藏无帖提示
            $list.show();
            $noreplies.hide();
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
            // 清除缓存，防止重复显示
            localStorage.removeItem('latestPost');
        },
        generatePostTag : function(tag) {
            // tag不存在，不作处理
            if (!tag) {
                return;
            }
            var html = '', tagClass = '', tagName = '', data = {};
            if (tag == 11) {
                data = [
                    {
                        tagClass : 'top',
                        tagName  : '置顶'
                    }
                ];
                html = lib.template2(data, '#post_tag_template');
            }
            return html;
        },
        showCtrMenu     : function($this) {
            var postType = $this.attr('type');
            var forbidden = parseInt($this.attr('forbidden'));
            var $ctrbtn = $this.find('span.btn_ctrl');
            var ordinary = ($this.attr('userType') == 'admin') ? false : true;
            // 设置菜单显示内容及事件回调
            var option = {};
            option['title'] = '选择操作';
            // 设置不同用户菜单的显示
            if (ordinary) {
                option['data'] = [
                    {
                        text : '删除',
                        name : 3
                    }
                ];
            } else {
                // 设置置顶帖与非置顶帖菜单的显示
                if (postType == '11') {
                    // 设置禁言用户和非禁言用户菜单的显示
                    if (forbidden) {
                        option['data'] = [
                            {
                                text : '取消置顶',
                                name : 2
                            },
                            {
                                text : '删除',
                                name : 3
                            },
                            {
                                text : '取消禁言',
                                name : 5
                            }
                        ];
                    } else {
                        option['data'] = [
                            {
                                text : '取消置顶',
                                name : 2
                            },
                            {
                                text : '删除',
                                name : 3
                            },
                            {
                                text : '禁言',
                                name : 4
                            }
                        ];
                    }
                } else {
                    // 设置禁言用户和非禁言用户菜单的显示
                    if (forbidden) {
                        option['data'] = [
                            {
                                text : '置顶',
                                name : 1
                            },
                            {
                                text : '删除',
                                name : 3
                            },
                            {
                                text : '取消禁言',
                                name : 5
                            }
                        ];
                    } else {
                        option['data'] = [
                            {
                                text : '置顶',
                                name : 1
                            },
                            {
                                text : '删除',
                                name : 3
                            },
                            {
                                text : '禁言',
                                name : 4
                            }
                        ];
                    }
                }
            }
            option['callback'] = function(name) {
                switch (name) {
                    case 1:
                        M.stickPost();
                        break;
                    case 2:
                        M.unstickPost();
                        break;
                    case 3:
                        M.deletePost();
                        break;
                    case 4:
                        M.muteUser();
                        break;
                    case 5:
                        M.unMuteUser();
                        break;
                    default:
                        $('#_menu').hide();
                        break;
                }
            };
            if (window.KalaGameUi && KalaGameUi.showSelectDialog) {
                KalaGameUi.showSelectDialog(option);
            } else {
                lib.showOptMenu(option);
            }
        },
        setPostPosition : function($reply, newPostInfo) {
            // 修改帖子更新时间
            var serverTime = newPostInfo.serverTime;
            if (serverTime) {
                $reply.attr('lastUpdateTime', serverTime);
                $reply.find('[postTime]').html('几秒前');
            }
            var index = 0, $first = null;
            var postType = $reply.attr('type');
            var $postList = $('#post_list li');
            var stickCount = $postList.find('span.top').length;
            var $plainList = $postList.slice(stickCount);
            // 置顶帖和普通帖
            if (postType == '11') {
                index = $postList.index($reply);
                $first = $postList.first();
            } else {
                index = $plainList.index($reply);
                $first = $plainList.first();
            }
            if (index > 0) {
                $reply.insertBefore($first);
            }
            // 更新缓存数据
            delete newPostInfo['__setPos'];
            delete newPostInfo['serverTime'];
            lib.setSessionItem('newPostInfo', JSON.stringify(newPostInfo));
        }
    };
    var C = {
        init                    : function() {
            // 绑定显示帖子内容事件
            C.bindShowPostDetailEvent();
            // 绑定帖子设置事件
            M.retrievePermission();
            // 绑定显示用户信息事件
            //这里很无语，用lib.bindShowUserInfoEvent('#post_list');就阻止不了冒泡
            //所以，只有写在本页面才能阻止。有空研究研究。
            C.bindShowUserInfoEvent('#post_list');
            // 管理菜单事件
            if (window.KalaGameUi && KalaGameUi.showReplyBtn) {
                $("#game_bbslist").css("padding-bottom", "0px");
            } else {
                $('#post_list').on(gc.click, 'span.btn_ctrl', function() {
                    var $this = $(this);
                    currentPost = $this.parent().parent();
                    V.showCtrMenu(currentPost);
                    return false;
                });
                $('#game_subpost_box').show();
            }
            // 提取新帖
            $('#post_reminder').on(gc.click, M.loadNewPosts);
        },
        bindShowPostDetailEvent : function() {
            $('#post_list').on(gc.click, 'li', function() {
                var $this = $(this);
                var postId = $this.attr('postId');
                var boardId = $this.attr('boardId');
                lib.setParam('postId', postId);
                lib.setParam('boardId', boardId);
                lib.setSessionItem('lz', $this.attr('author'));
                if (window.KalaGameUi && KalaGameUi.openBbsContentActivity) {
                    KalaGameUi.openBbsContentActivity("game-bbscontent", "&" + lib.getAllParam());
                } else {
                    lib.redirect('game-bbscontent');
                }
            });
        },
        bindShowUserInfoEvent   : function(selector) {
            var channel = lib.getParam("channel");
            if (lib.getParam("channel") == "apple") {
                return;
            }
            $(selector).on(gc.click, 'li img[userId]', function(event) {
                var $this = $(this);
                var userId_list = $this.attr('userId');
                if (userId_list == 0) {
                    lib.showTip('用户不存在！');
                } else {
                    lib.setParam('userId', userId_list);
                    if (userId_list == gc.userId && channel != "mobage" && channel != "xiaomi") {
                        if (channel == "client" && window.KalaGameClient && KalaGameClient.openHouse) {
                            KalaGameClient.openHouse();
                        } else {
                            lib.redirectClient('user-edit_info');
                        }
                    } else {
                        if (channel == "client" && window.KalaGameClient && KalaGameClient.openHouse) {
                            KalaGameClient.openHouse(userId_list);
                        } else {
                            lib.redirectClient('user-userinfo');
                        }
                    }
                }
                return false;
            });
        },
        bindCtrMenuEvent        : function($this) {
            var $ctrbtn = $this.find('span.btn_ctrl');
            var postType = $this.attr('type');
            var ordinary = ($this.attr('userType') == 'admin') ? false : true;
            // 客户端保存当前帖子
            var postAuthor = $this.attr('author');
            var hasPermission = !ordinary || (userId == postAuthor);
            if (window.KalaGame) {
                currentPost = $this;
                hasPermission && V.showCtrMenu($this);
            } else {
                if (event.type == 'mouseout') {
                    $ctrbtn.hide();
                } else {
                    hasPermission && $ctrbtn.show();
                }
            }
            // 缓存数据
            var postInfo = {
                appId           : lib.getParam('gameId'),
                postId          : $this.attr('postId'),
                boardId         : $this.attr('boardId'),
                forbiddenUserId : $this.attr('author')
            };
            lib.setSessionItem('postInfo', JSON.stringify(postInfo));
        },
        initSlider              : function() {
            var timeout = parseInt($('.iosSlider').attr('timeout'));
            $('.iosSlider').iosSlider({
                autoSlide      : true,
                autoSlideTimer : timeout,
                snapToChildren : true,
                infiniteSlider : true
            });
        }
    }
    // 初始化一次
    C.init();
    function init() {
        // 是否显示banner
        M.getUserId();
        // 获取新消息数量
        //TODO 暂时关闭
        //M.retrieveNewMsgCount();
        // 相同游戏ID使用缓存数据
        var appId = lib.getParam('gameId');
        if (appId != gameId) {
            $('#post_list').html('');
            // 获取帖子列表
            M.getPostList();
            gameId = appId;
        } else {
            var response = localStorage.getItem('latestPost');
            if (response) {
                V.showLatestPost(response);
                //删除缓存
                localStorage.removeItem('latestPost');
            } else {
                var newPostInfo = JSON.parse(lib.getSessionItem('newPostInfo'));
                // 设置浏览数和回复数
                if (newPostInfo) {
                    var views = newPostInfo.views;
                    var postId = newPostInfo.postId;
                    var replies = newPostInfo.replies;
                    var $reply = $('#post_list').find('li[postId="' + postId + '"]');
                    if ($reply.length) {
                        $reply.find('b.replies').html(replies);
                        $reply.find('b.clicks').html(views);
                        // 修改帖子位置
                        var setPos = newPostInfo['__setPos'];
                        if (setPos) {
                            V.setPostPosition($reply, newPostInfo);
                        }
                    }
                }
            }
        }
        M.getGameInfo();
        //绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#post_list'));
        // 定时获取新帖
        M.newPostReminder.fetch();
        // pull to refresh callback
        gc.pullToRefresh = function() {
            lib.clearTimer();
            // 隐藏新消息提示
            $('#post_reminder').hide();
            M.getPostList(0, true);
            M.retrieveNewMsgCount();
            // 上报下拉刷新
            gc.reportAction(lib.getParam('page'), 'pullToRefresh', 0);
        }
        // 点击顶部按钮回调
        gc.editBtnCallback = function(n) {
            if (n === 0) {
                lib.redirectClient('user-message');
            }
        }
    }

    function updateTime(serverTime) {
        var $postList = $('#post_list li');
        $postList.each(function() {
            var $this = $(this);
            var createTime = $this.attr('lastUpdateTime');
            if (serverTime && createTime) {
                var replyTime = lib.dateDiff(serverTime, createTime);
                $this.find('[postTime]').html(replyTime);
            }
        });
    }

    function onStop() {
        lib.clearTimer();
        console.log('=======leaving page: ' + lib.getParam('page') + ' & stop timer=======');
    }
});
