define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), com = require('gameComm'), lazyload = require('lazyload');
    exports.init = init;
    exports.onStop = onStop;
    exports.updateTime = updateTime;

    // 列表默认的显示数目
    var nDefaultCount = 10 * lib.listCountMultiples();
    var $currentReply, strServerTime, strLastReplyId, strUserId, strTempReplyId = null, isShowNewReply = false;
    var uploadImages = [];

    var M = {
        getReplyDetail : function() {
            var strUrl = lib.bbsUrl + 'forum/getReplyDetail';
            var objData = {
                appId : lib.getParam('gameId'),
                postId : lib.getParam('postId'),
                boardId : lib.getParam('boardId'),
                replyId : lib.getParam('replyId')
            };

            // 显示真实数据前，显示“加载中...”
            V.showReplyDetailDefault();

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    // 保存服务端时间
                    strServerTime = objResult.serverTime;
                    V.showReplyDetail(objResult);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            }, {
                cache : true,
                noLoading : true
            });
        },
        getReplyList : function(nStart) {
            var strUrl = lib.bbsUrl + 'forum/getPostReplyList';
            var objData = {
                appId : lib.getParam('gameId'),
                postId : lib.getParam('postId'),
                boardId : lib.getParam('boardId'),
                parentId : lib.getParam('replyId'),
                start : nStart,
                count : 1000
            }

            if (window.KalaGameUi && !nStart) {
                lib.showLoading();
            }

            lib.postCrossList(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    // 保存服务端时间
                    strServerTime = objResult.serverTime;
                    V.showReplyList(objResult, nStart);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            }, function() {
                M.getReplyList(nStart);
            }, false);
        },
        submitReply : function($btn, strReplyId) {
            var isDisabled = $btn.hasClass('ontimer');
            if (!isDisabled) {
                var $content = $('#reply_content');
                var strContent = $.trim($content.val());
                if (!strContent) {
                    lib.showTip('请输入回复内容！');
                    return;
                }

                var strUrl = lib.bbsUrl + 'forum/replyPost';
                var objData = {
                    appId : lib.getParam('gameId'),
                    postId : lib.getParam('postId'),
                    boardId : lib.getParam('boardId'),
                    parentId : strReplyId,
                    content : strContent
                };

                $btn.addClass('ontimer');
                lib.postCross(strUrl, objData, function(objResult) {
                    $btn.removeClass('ontimer');
                    if (objResult.result == 1) {
                        V.showLatestReply(objResult, $btn);
                    } else {
                        if (objResult.ret == -6001) {
                            lib.showVcode(function() {
                                M.submitReply($btn, strReplyId);
                            });
                        }
                        // 失败，显示提示信息
                        lib.showTip(objResult.msg);
                    }
                });
            }
        },
        getUserId : function() {
            var strUrl = lib.userUrl + 'detail/getAccountInfo';
            lib.postCross(strUrl, function(objResult) {
                if (objResult.result == 1) {
                    strUserId = objResult.data.userId;
                    gc.userId = strUserId;
                }
            }, {
                cache : true
            });
        },
        retrievePermission : function() {
            var strUrl = lib.bbsUrl + 'forum/checkPermission';
            var objData = {
                appId : lib.getParam('gameId')
            }

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    var $replyList = $('#reply_list');
                    var $replyDetail = $('#reply_detail');
                    // 解绑longTap事件
                    $replyList.off(gc.longTap, 'dl');

                    // 重新绑定帖子设置事件
                    if (objResult.valid) {
                        // 回复详情
                        $replyDetail.on(gc.longTap, function() {
                            var $reply = $(this);
                            $reply.attr('userType', 'admin');
                            C.bindCtrMenuEvent($reply);
                        });
                        // 回复的回复列表
                        $replyList.on(gc.longTap, 'dl', function() {
                            var $reply = $(this);
                            $reply.attr('userType', 'admin');
                            C.bindCtrMenuEvent($reply, true);

                            return false;
                        });
                    } else {
                        // 回复详情
                        $replyDetail.on(gc.longTap, function() {
                            var $reply = $(this);
                            var strPostAuthor = $reply.attr('author');

                            if (strUserId != strPostAuthor) {
                                if (window.KalaGame) {
                                    lib.showTip('对不起，您没有权限！');
                                }

                                return;
                            }
                            $reply.attr('userType', 'ordinary_user');
                            C.bindCtrMenuEvent($reply);
                        });
                        // 回复的回复列表
                        $replyList.on(gc.longTap, 'dl', function() {
                            var $reply = $(this);
                            var strPostAuthor = $reply.attr('author');

                            if (strUserId != strPostAuthor) {
                                if (window.KalaGame) {
                                    lib.showTip('对不起，您没有权限！');
                                }

                                return;
                            }
                            $reply.attr('userType', 'ordinary_user');
                            C.bindCtrMenuEvent($reply, true);

                            return false;
                        });
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            }, {
                cache : true,
                noLoading : true
            });
        },
        deleteReply : function() {
            lib.confirm("确定要删除该条回复？", function(nIndex) {
                if (nIndex != 1) {
                    return;
                }

                var strUrl = lib.bbsUrl + 'forum/deleteReply';
                var strInfo = lib.getSessionItem('replyInfo');
                var objData = (strInfo && JSON.parse(strInfo)) || {};
                // 去除无用参数
                delete objData.forbiddenUserId;

                lib.postCross(strUrl, objData, function(objResult) {
                    if (objResult.result == 1) {
                        if ($currentReply) {
                            var isBtnRR = $($currentReply).find('span.btn_ctrl').attr('btnRR');
                            if (!isBtnRR) {
                                V.updatePostReplyCount(true);
                                $currentReply.remove();
                            } else {
                                var $parent = $($currentReply).parentsUntil('#reply_list').last();
                                var strReplyId = $parent.attr('replyId');
                                V.setNewReplyCount(strReplyId, true);
                                $currentReply.remove();

                                var $wrap = $('#reply_list');
                                if (!$wrap.find('dl').length) {
                                    $wrap.addClass('invisible');
                                }
                            }
                            lib.showTip('操作成功！');
                        }
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(objResult.msg);
                    }
                });
            });
        },
        muteUser : function() {
            lib.confirm("确定要禁言该用户？", function(nIndex) {
                if (nIndex != 1) {
                    return;
                }

                var strUrl = lib.bbsUrl + 'forum/forbiddenUser';
                var strInfo = lib.getSessionItem('replyInfo');
                var objData = {
                    appId : lib.getParam('gameId'),
                    forbiddenUserId : (strInfo && JSON.parse(strInfo)).forbiddenUserId
                };

                lib.postCross(strUrl, objData, function(objResult) {
                    if (objResult.result == 1) {
                        $currentReply && $currentReply.attr('forbidden', 1);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(objResult.msg);
                    }
                });
            });
        },
        unMuteUser : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要取消该用户的禁言？", function(nIndex) {
                if (nIndex != 1) {
                    return;
                }

                var strUrl = lib.bbsUrl + 'forum/cancelForbiddenUser';
                var strInfo = lib.getSessionItem('replyInfo');
                var objData = {
                    appId : lib.getParam('gameId'),
                    forbiddenUserId : (strInfo && JSON.parse(strInfo)).forbiddenUserId
                };

                lib.postCross(strUrl, objData, function(objResult) {
                    if (objResult.result == 1) {
                        $currentReply && $currentReply.attr('forbidden', 0);
                        lib.showTip('操作成功！');
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(objResult.msg);
                    }
                });
            });
        },
        formatData : function(objData) {
            if (!objData) {
                return;
            }

            // 设置头像
            var strIcon = objData.icon;
            objData.icon = strIcon ? strIcon : gc.defaultIcon_96;
            var strCreateTime = objData.createTime;
            if (strCreateTime) {
                objData.postTime = lib.dateDiff(strServerTime, objData.createTime);
            } else {
                objData.postTime = '加载中...';
            }

            // 解析表情
            var strContent = objData.content;
            var rPattern = /\[[\u4e00-\u9fa5]+\]/ig;

            if (strContent) {
                objData.content = strContent.replace(rPattern, com.parseEmotionPath);
            }

            // 解析图片
            var objAttach = objData.attach;
            if (objAttach) {
                var strHtml = com.parseUploadedImages(strContent, objAttach);
                objData.content += strHtml;
            }

            // 设置是否加V
            var isAuthenticated = objData.authenticated;
            objData.addV = '';
            if (isAuthenticated == '1') {
                objData.addV = 'admin';
            }

            return objData;
        },
        formatDataList : function(arrDataList, isReply) {
            var nLen = arrDataList.length;
            if (!nLen) {
                return;
            }

            // 匹配表情
            var rPattern = /\[[\u4e00-\u9fa5]+\]/ig;

            for (var i = 0; i < nLen; i++) {
                var objReply = arrDataList[i];
                if (isReply) {
                    objReply.replyTag = lib.getSessionItem('lz') == objReply.author ? '楼主' : '';
                }
                var strHtml = V.generateReplyTag(objReply.replyTag);

                objReply.replyTags = strHtml ? strHtml : '';
                objReply.replyTime = lib.dateDiff(strServerTime, objReply.createTime);

                // 设置禁言标识
                if (!objReply.forbidden) {
                    objReply.forbidden = 0;
                } else {
                    objReply.forbidden = 1;
                }

                // 设置默认用户头像
                if (!objReply.icon) {
                    objReply.icon = gc.defaultIcon_96;
                }

                // 设置楼层信息
                if (!isReply) {
                    // 楼层样式
                    objReply.floorStyle = '';
                    if (objReply.floor == 2) {
                        objReply.floor = '沙发';
                        objReply.floorStyle = 'sofa';
                    } else if (objReply.floor == 3) {
                        objReply.floor = '板凳';
                    } else if (objReply.floor == 4) {
                        objReply.floor = '地板';
                    } else if (objReply.floor == 5) {
                        objReply.floor = '下水道';
                    } else {
                        objReply.floor += '楼';
                    }
                }

                // 解析表情
                var replyContent = objReply.content;
                if (replyContent) {
                    objReply.content = replyContent.replace(rPattern, com.parseEmotionPath);
                }

                // 解析图片
                var objAttach = objReply.attach;
                if (objAttach) {
                    var contentHtml = com.parseUploadedImages(replyContent, objAttach);
                    objReply.content += contentHtml;
                }

                // 设置是否加V
                var isAuthenticated = objReply.authenticated;
                objReply.addV = '';
                if (isAuthenticated == '1') {
                    objReply.addV = 'admin';
                }
            }

            return arrDataList;
        },
        loadMore : function() {
            $('#reply_reminder').hide();
            var $replyList = $('#reply_list');
            var nStart = $replyList.find('li').not('[latestItem]').length;
            M.getReplyList(nStart);
        },
        parseEmotionPath : function(objEmotion) {
            var objEmotions = com.emotions;

            var objResult = objEmotions.filter(function(em) {
                return (objEmotion == '[' + em['name'] + ']') || (objEmotion == '[' + em['name_old'] + ']');
            });

            if (objResult.length) {
                objEmotion = '<img src="' + objResult[0].icon + '" />';
            }

            return objEmotion;
        }
    };

    var V = {
        showReplyDetail : function(objResult) {
            var objData = M.formatData(objResult.data);
            lib.template(objData, '#post_content');
            var $html = $('#post_content');

            if (!objResult.__default) {
                var $li = $('#post_content').find('li');
                // 设置加V样式
                $li.find('[name="nickName"]').addClass(objData.addV);
                // 设置回复中图片的尺寸
                lib.setImgSize($html.find('p.comment'));
                // 设置信息
                $li.attr('author', objData.author);
                $li.attr('replies', objData.replies);
                $li.attr('createTime', objData.createTime);
                $li.find('img[name="icon"]').attr('userId', objData.author);
                $('#btn_face').attr('replyId', objData.replyId);
                $('#btn_submit').attr('replyId', objData.replyId);
                $('#reply_content').attr('contentId', objData.replyId);

                // 更新回复数
                V.updatePostViewCount(objData);
            }

            // 图片渐显
            $('#post_content img[data-original]').lazyload();
        },
        showReplyDetailDefault : function() {
            // 页面切换显示加载中
            var defaultData = {
                __default : true,
                objData : {
                    subject : '',
                    nickName : '',
                    content : '加载中...',
                }
            };

            // 去除已存在图片
            $('[name=icon]').removeAttr('src');
            V.showReplyDetail(defaultData);
        },
        showReplyList : function(objResult, nStart) {
            // 设置禁言以及默认头像
            M.formatDataList(objResult.list);

            // 如为页面初始化，则清空html
            !nStart && $('#reply_list').html('');

            var $html = lib.showCacheList2(objResult, '#reply_list_template', '#reply_list');
            // 绑定延迟加载图片事件
            var $wrap = $('#reply_list').parent();
            if ($html) {
                $wrap.removeClass('invisible');
                lib.setImgSize($html.find('p.comment'));
                $html.find('img').lazyload();
            } else {
                $wrap.addClass('invisible');
            }

            // 倒序显示结束后，隐藏loading及清除缓存数据
            if (window.KalaGameUi) {
                // 隐藏加载中
                lib.hideLoading();
            }
        },
        showLatestReply : function(objResult, $btn) {
            var $wrap = $('#reply_list');
            var strReplyId = $btn.attr('replyId');

            // 清空并隐藏回复框
            var $replyBox = $btn.parent();
            $btn.removeClass('hover');
            $replyBox.addClass('invisible');
            $('#reply_content').val('');
            com.updateHeight($('#reply_content'));
            // 帖子数据 - 设置是否楼主
            var objData = objResult.data;
            // 楼主
            objData.replyTag = lib.getSessionItem('lz') == objData.author ? '楼主' : '';

            var arrDataList = M.formatDataList([objData], true);
            var $html = $(lib.template2(arrDataList, '#reply_list_template'));
            $html.attr('latestItem', 'true');
            $html.appendTo($wrap);
            $wrap.removeClass('invisible');

            // 设置回复中图片的尺寸
            lib.setImgSize($html.find('p.comment'));
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();

            lib.showTip('回复成功！');
        },
        generateReplyTag : function(strTag) {
            // tag不存在，不作处理
            if (!strTag) {
                return;
            }

            var tagClass = '', tagName = '', objData = {};

            if (strTag == '楼主') {
                objData = [{
                    tagClass : 'lz',
                    tagName : strTag
                }];
            }

            return lib.template2(objData, '#reply_tag_template');
        },
        updatePostReplyCount : function(isRemoveReply) {
            var objNewPostInfo = JSON.parse(lib.getSessionItem('newPostInfo'));

            if (objNewPostInfo) {
                // 更新回复数
                if (isRemoveReply) {
                    objNewPostInfo.replies = parseInt(objNewPostInfo.replies) - 1;
                } else {
                    objNewPostInfo.replies = parseInt(objNewPostInfo.replies) + 1;
                    // 在帖子列表页面，帖子需要改变位置
                    objNewPostInfo['__setPos'] = true;
                    objNewPostInfo['serverTime'] = strServerTime;
                }

                lib.setSessionItem('newPostInfo', JSON.stringify(objNewPostInfo));
            }
        },
        updatePostViewCount : function(objData) {
            if (!objData) {
                return;
            }
            // 保存回复信息
            var objNewPostInfo = {
                views : ++objData.views,
                replies : objData.replies,
                postId : objData.postId
            };

            lib.setSessionItem('newPostInfo', JSON.stringify(objNewPostInfo));
        },
        setNewReplyCount : function(strReplyId, isRemoveReply) {
            var $reply = $('#reply_list').find('li[replyId="' + strReplyId + '"]');
            var $span = $reply.find('span.datainfo_replies');
            var strContent = $.trim($span.html());
            var nCount = parseInt(strContent);

            if (!isNaN(nCount)) {
                if (isRemoveReply) {
                    nCount = (nCount - 1) < 0 ? 0 : (nCount - 1);
                } else {
                    nCount = nCount + 1;
                }

                $span.html(nCount);
            }
        },
        showCtrMenu : function($this) {
            var nForbidden = parseInt($this.attr('forbidden'));
            var $ctrbtn = $this.find('span.btn_ctrl');
            var isOrdinary = ($this.attr('userType') == 'admin') ? false : true;
            // 设置菜单显示内容及事件回调
            var objOption = {};
            objOption['title'] = '选择操作';
            // 设置不同用户菜单的显示
            if (isOrdinary) {
                objOption['data'] = [{
                    text : '删除',
                    name : 3
                }];
            } else {
                // 设置禁言用户和非禁言用户菜单的显示
                if (nForbidden) {
                    objOption['data'] = [{
                        text : '删除',
                        name : 3
                    }, {
                        text : '取消禁言',
                        name : 5
                    }];
                } else {
                    objOption['data'] = [{
                        text : '删除',
                        name : 3
                    }, {
                        text : '禁言',
                        name : 4
                    }];
                }
            }
            objOption['callback'] = function(nName) {
                switch (nName) {
                    case 3:
                        M.deleteReply();
                        break;
                    case 4:
                        M.muteUser();
                        break;
                    case 5:
                        M.unMuteUser();
                        break;
                    default:
                        $('#_menu').hide();
                        break;
                }
            };
            if (window.KalaGameUi && KalaGameUi.showSelectDialog) {
                KalaGameUi.showSelectDialog(objOption);
            } else {
                lib.showOptMenu(objOption);
            }
        }
    };

    var C = {
        init : function() {
            M.getUserId();
            // 绑定回复设置事件
            M.retrievePermission();
            C.bindShowOriginalImageEvent();
            C.bindToggleReplyBoxEvent();
            // 绑定显示用户信息事件
            lib.bindShowUserInfoEvent('#reply_list, #post_content');
            C.bindShowEmotionEvent();
            C.bindCtrMenuVisibilityEvent();
            C.bindReplyEvent();
            C.bindAutoHeightEvent('#game_bbsreply');
        },
        bindAutoHeightEvent : function(selector) {
            if (lib.getParam("channel") != "apple") {
                var $shadom = $('<textarea type="text" style="position: absolute; border-width: 0px; padding: 0px; visibility: hidden;"></textarea>');
                $(selector).on("input", "textarea", function() {
                    com.updateHeight($(this));
                });
            }
        },
        updateScroll : function($li, isForceScroll) {
            var nReplyTop = $li.offset().top;
            var nReplyHeight = $li.outerHeight(true);
            var nBottomBarHeight = $('.gamebbs_btnbox:visible').outerHeight(true);
            var nScrollHeight = nReplyTop + nReplyHeight + nBottomBarHeight - window.innerHeight;

            var nScrollTop = document.body.scrollTop;
            if (nScrollHeight > 0 && ((nScrollHeight > nScrollTop) || isForceScroll)) {
                $('body').animate({
                    'scrollTop' : nScrollHeight
                });
            }
        },
        bindReplyEvent : function() {
            $('#btn_submit').on(gc.click, function() {
                var $this = $(this);
                var strReplyId = $this.attr('replyId');

                $('#emotion_wrap').addClass('invisible');
                M.submitReply($this, strReplyId);
            });

            // 提取新回复
            $('#reply_reminder').on(gc.click, function() {
                $('#reply_reminder').hide();
                // 设置提取新消息标识
                isShowNewReply = true;
                var $replyList = $('#reply_list');
                var nStart = $replyList.find('li').not('[latestItem]').length;

                M.getReplyList(nStart);
            });
        },
        bindCtrMenuVisibilityEvent : function() {
            // 管理菜单事件
            if (!window.KalaGame) {
                $('#reply_list').on(gc.click, 'span.btn_ctrl', function() {
                    var $this = $(this);
                    var isBtnRR = $this.attr('btnRR');
                    var $parents = $this.parentsUntil('#post_content');
                    if (isBtnRR == 'true') {
                        $parents = $this.parentsUntil('#reply_list');
                        $currentReply = $parents.last();
                        V.showCtrMenu($currentReply, true);
                    } else {
                        $currentReply = $parents.last();
                        V.showCtrMenu($currentReply);
                    }

                    return false;
                });
            }
        },
        bindCtrMenuEvent : function($this, isBtnRR) {
            var $ctrbtn = isBtnRR ? $this.find('span.btn_ctrl') : $this.find('span.btn_ctrl').not('[btnRR]');
            var isOrdinary = ($this.attr('userType') == 'admin') ? false : true;
            var $parents = isBtnRR ? $this.parentsUntil('#reply_list') : $this.parentsUntil('#post_content');

            // 客户端保存当前回复
            var strPostAuthor = $this.attr('author');
            var hasPermission = !isOrdinary || (strUserId == strPostAuthor);
            if (window.KalaGame) {
                $currentReply = $parents.last();
                hasPermission && V.showCtrMenu($this);
            } else {
                if (event.type == 'mouseout') {
                    $ctrbtn.hide();
                } else {
                    hasPermission && $ctrbtn.show();
                }
            }

            // 缓存数据
            var replyInfo = {
                appId : lib.getParam('gameId'),
                postId : lib.getParam('postId'),
                boardId : lib.getParam('boardId'),
                replyId : $this.attr('replyId'),
                forbiddenUserId : $this.attr('author')
            };

            // 回复的回复添加parentId
            if (isBtnRR) {
                replyInfo.parentId = $this.parentsUntil('#reply_list').last().attr('replyId');
            }

            lib.setSessionItem('replyInfo', JSON.stringify(replyInfo));
        },
        bindShowOriginalImageEvent : function() {
            $('#reply_list, #post_content').on(gc.click, 'p.comment img[data-original]', function() {
                var $this = $(this);
                var $content = $this.parent();

                // 设置当前点击图片的索引
                var nIndex = $content.find('img[data-original]').index($this);
                lib.showOriginalImg($content, nIndex);

                // 阻止事件冒泡
                return false;
            });
        },
        bindToggleReplyBoxEvent : function() {
            $('#post_content').on(gc.click, 'li #reply_detail, dl', function() {
                var $this = $(this);
                var $reply = $this;
                var strReplyId = $reply.attr('replyId');

                // 关闭打开的回复框
                var $replyBox = $('#reply_box');
                var $replyList = $('#reply_list').find('dl');
                if ($replyList.length) {
                    $replyBox.parent().removeClass('invisible');
                    $replyBox.toggleClass('invisible');
                } else {
                    $replyBox.parent().toggleClass('invisible');
                    $replyBox.removeClass('invisible');
                }

                // 设置回复的回复输入框的位置
                var visibility = $replyBox.hasClass('invisible');
                if (!visibility) {
                    C.updateScroll($reply, false);

                    // 穿透问题，可能会选中输入框
                    $reply.find("textarea").attr('disabled', 'disabled');
                    setTimeout(function() {
                        $reply.find("textarea").removeAttr('disabled');
                    }, 300);
                }

                $('#emotion_wrap').addClass('invisible');
            });
        },
        bindShowEmotionEvent : function() {
            $('#btn_face').on(gc.click, function() {
                var $this = $(this);
                var strReplyId = $this.attr('replyId');

                if (strReplyId) {
                    strTempReplyId = strReplyId;
                }

                com.showEmotions(strTempReplyId);
            });
        }
    }

    // 初始化一次
    C.init();

    function init() {
        // 相同游戏ID使用缓存数据
        var postId = lib.getParam('postId');
        if (postId != strLastReplyId) {
            $('#emotion_wrap').addClass('invisible');
            $('#reply_list').html('');
            // 显示loading
            $('#spinner_list').show();
            $('#loadingText').css('visibility', 'visible');
            // 获取帖子列表
            M.getReplyList(0);
            // 获取帖子详细信息
            M.getReplyDetail();

            strLastReplyId = postId;
        }

        // 绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#reply_list'));
    }

    function updateTime(strServerTime) {
        var $replyList = $('#post_content li div span[createTime], #reply_list dl span[createTime]');

        $replyList.each(function() {
            var $this = $(this);
            var strCreateTime = $this.attr('createTime');

            if (strServerTime && strCreateTime) {
                var strReplyTime = lib.dateDiff(strServerTime, strCreateTime);
                $this.html(strReplyTime);
            }
        });
    }

    function onStop() {
        lib.clearTimer();
        console.log('=======leaving page: ' + lib.getParam('page') + ' & stop timer=======');
    }

});
