define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload'), com = require('gameComm');
    exports.init = init;
    exports.updateTime = updateTime;
    exports.pullToRefresh = function() {
        lib.clearTimer();
        M.getQuestionReplyList(0, defaultCount, true);
        // 上报下拉刷新
        gc.reportAction(lib.getParam('page'), 'pullToRefresh', 0);
    };
    
    // 列表默认的显示数目
    var defaultCount = 10 * lib.listCountMultiples();
    var serverTime, lastQuestionId;
    var M = {
        getQuestionDetail    : function() {
            var url = lib.bbsUrl + 'question/getQuestionDetail';
            var params = {
                appId      : lib.getParam('gameId'),
                questionId : lib.getParam('questionId')
            };
            var hasGetQuestionReplyList = false;
            lib.postCross(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showQuestionDetail(response);
                    if (!hasGetQuestionReplyList) {
                        hasGetQuestionReplyList = true;
                        // 获取帖子列表
                        M.getQuestionReplyList();
                    }
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
            }, {
                cache     : true,
                noLoading : true
            });
        },
        getQuestionReplyList : function(start, listCount, isPullToRefresh) {
            var url = lib.bbsUrl + 'question/getQuestionReplyList';
            var params = {
                appId      : lib.getParam('gameId'),
                start      : start || 0,
                count      : listCount || defaultCount,
                questionId : lib.getParam('questionId')
            }
            lib.postCrossList(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showQuestionReplyList(response, start);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
                // 客户端关闭刷新
                if (isPullToRefresh && window.KalaGameUi && KalaGameUi.closeRefresh) {
                    KalaGameUi.closeRefresh();
                }
            }, function() {
                M.getQuestionReplyList(start);
            }, false);
        },
        formatData           : function(data) {
            if (!data) {
                return;
            }
            // 设置头像
            var icon = data.icon;
            data.icon = icon ? icon : gc.defaultIcon_96;
            var createTime = data.createTime;
            if (createTime) {
                data.postTime = lib.dateDiff(serverTime, createTime);
            } else {
                data.postTime = '加载中...';
            }
            // 解析表情
            // var postCount = data.content;
            // var pattern = /\[[\u4e00-\u9fa5]+\]/ig;
            //
            // if (postCount) {
            // data.content = postCount.replace(pattern, com.parseEmotionPath);
            // }
            return data;
        },
        formatDataList       : function(dataList, newReply) {
            var len = dataList.length;
            if (!len) {
                return;
            }
            // 匹配表情
            var pattern = /\[[\u4e00-\u9fa5]+\]/ig;
            // 去除重复问题
            if (newReply) {
                var replyList = [], key = 'replyId';
                $('#faq_msg li').each(function() {
                    replyList.push($(this).attr(key))
                });
                dataList = lib.removeDuplicated(replyList, dataList, key);
                len = dataList.length;
            }
            for (var i = 0; i < len; i++) {
                var reply = dataList[i];
                reply.replyTime = lib.dateDiff(serverTime, reply.createTime);
                // 设置默认用户头像
                if (!reply.icon) {
                    reply.icon = gc.defaultIcon_96;
                }
                // 设置回复者显示颜色
                reply.userTagClass = 'kf_reply';
                if (reply.replyTag == '我') {
                    reply.userTagClass = '';
                }
                // 解析表情
                // var replyContent = reply.content;
                // if (replyContent) {
                // reply.content = replyContent.replace(pattern, com.parseEmotionPath);
                // }
            }
            return dataList;
        },
        loadMore             : function() {
            var $replyList = $('#faq_msg');
            var $spinner = $('#spinner_list');
            // 延迟显示
            var timeout = parseInt($spinner.attr('timeout'));
            lib.setTimeout(function() {
                var start = $replyList.find('li').not('[latestReply]').length;
                M.getQuestionReplyList(start);
            }, timeout);
        }
        // parseEmotionPath : function(emotion) {
        // var emotions = com.emotions;
        //
        // var result = emotions.filter(function(em) {
        // return emotion == '[' + em.name + ']';
        // });
        //
        // if (result.length) {
        // emotion = '<img src="' + result[0].icon + '" />';
        // }
        //
        // return emotion;
        // }
    };
    var V = {
        showQuestionDetail    : function(response) {
            var data = M.formatData(response.data);
            lib.template(data, '#faq_desc');
            $('#faq_contentbox').show();
        },
        showQuestionReplyList : function(response, start) {
            // 设置禁言以及默认头像
            var $faq_msg = $('#faq_msg');
            var dataList = M.formatDataList(response.list);
            // 页面初始化，清除存在的列表
            if (!start) {
                $faq_msg.html('');
            }
            // 显示缓存数据
            var $html = lib.showCacheList2(response, '#faq_msg_template', $faq_msg);
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
        },
        showLatestReply       : function(response) {
            response = JSON.parse(response);
            var $faq_msg = $('#faq_msg li');
            // 帖子数据
            var dataList = M.formatDataList([response.data], true);
            var $html = $(lib.template2(dataList, '#faq_msg_template'));
            if ($faq_msg.length) {
                $html.insertBefore($faq_msg.first());
            } else {
                $html.appendTo($('#faq_msg'));
            }
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
            // 清空缓存数据
            lib.removeSessionItem('latestReply');
        }
    };
    var C = {
        init : function() {
            if (!window.KalaGame) {
                $("#game_reply_wrapper").show();
            }
        }
    }
    // 初始化一次
    C.init();
    function init() {
        // 相同问题ID使用缓存数据
        var questionId = lib.getParam('questionId');
        if (questionId != lastQuestionId) {
            $('#faq_msg').html('');
            // 显示loading
            $('#spinner_list').show();
            $('#loadingText').css('visibility', 'visible');
            // 获取帖子详细信息
            M.getQuestionDetail();
            lastQuestionId = questionId;
        } else {
            var response = lib.getSessionItem('latestReply');
            if (response) {
                V.showLatestReply(response);
            }
        }
        //绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#faq_msg'));
        // pull to refresh callback
        gc.pullToRefresh = exports.pullToRefresh;
    }

    function updateTime(serverTime) {
        var $replyList = $('#faq_msg li, #faq_desc li');
        $replyList.each(function() {
            var $this = $(this);
            var createTime = $this.attr('createTime');
            if (serverTime && createTime) {
                var replyTime = lib.dateDiff(serverTime, createTime);
                $this.find('[replyTime]').html(replyTime);
            }
        });
    }
});
