define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload'), com = require('gameComm');
    exports.init = init;
    exports.updateTime = updateTime;
    
    exports.pullToRefresh = function() {
        lib.clearTimer();
        M.getMyQuestionList(0, defaultCount, true);
        // 上报下拉刷新
        gc.reportAction(lib.getParam('page'), 'pullToRefresh', 0);
    };
    
    // 列表默认的显示数目
    var defaultCount = 10 * lib.listCountMultiples();
    var serverTime, lastGameId;
    var M = {
        getMyQuestionList : function(start, listCount, isPullToRefresh) {
            var url = lib.bbsUrl + 'question/getMyQuestionList';
            var params = {
                appId   : lib.getParam('gameId'),
                boardId : 2,
                start   : start || 0,
                count   : listCount || defaultCount
            }
            lib.postCrossList(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showMyQuestionList(response, start);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }
                // 客户端关闭刷新
                if (isPullToRefresh && window.KalaGameUi) {
                    KalaGameUi.closeRefresh();
                }
            }, function() {
                M.getMyQuestionList(start);
            });
        },
        formatDataList    : function(dataList, newQuestion) {
            var len = dataList.length;
            if (!len) {
                return;
            }
            // 去除重复问题
            if (newQuestion) {
                var questionList = [], key = 'questionId';
                $('#post_list li').each(function() {
                    questionList.push($(this).attr(key))
                });
                dataList = lib.removeDuplicated(questionList, dataList, key);
                len = dataList.length;
            }
            for (var i = 0; i < len; i++) {
                var post = dataList[i];
                var html = V.generateQuestionStatus(post);
                post.questionStatus = html;
                post.updateTime = lib.dateDiff(serverTime, post.lastUpdateTime);
                // 修改默认用户头像
                var icon = post.icon;
                if (!icon) {
                    post.icon = gc.defaultIcon_96;
                }
            }
            return dataList;
        },
        loadMore          : function() {
            var $postList = $('#post_list');
            var $spinner = $('#spinner_list');
            if ($postList.attr('hasMore') != 'true') {
                $spinner.hide();
                return;
            }
            // 延迟显示
            var timeout = parseInt($spinner.attr('timeout'));
            lib.setTimeout(function() {
                var start = $postList.find('li').length;
                M.getMyQuestionList(start);
            }, timeout);
        }
    };
    var V = {
        showMyQuestionList     : function(response, start) {
            var $postList = $('#post_list');
            var $noreplies = $('#noreplies');
            // 我打金牌客服
            if (lib.getParam('appId') == 10005) {
                $noreplies = $('#goldserverguide');
            }
            // 格式化数据
            var dataList = M.formatDataList(response.list);
            // 页面初始化，清除存在的列表
            if (!start) {
                $postList.html('');
            }
            if (dataList && dataList.length) {
                $postList.show();
                $noreplies.hide();
                // 显示缓存数据
                var $html = lib.showCacheList2(response, '#post_list_template', $postList);
                // 绑定延迟加载图片事件
                $html && $html.find('img').lazyload();
            } else {
                $('#spinner_list').hide();
                var count = $postList.find('li').length;
                !count && $noreplies.show();
            }
        },
        showLatestQuestion     : function(response) {
            var $postList = $('#post_list li');
            var $noreplies = $('#noreplies');
            response = JSON.parse(response);
            // 我打金牌客服
            if (lib.getParam('appId') == 10005) {
                $noreplies = $('#goldserverguide');
            }
            // 隐藏无回复提示
            $noreplies.hide();
            // 帖子数据
            var dataList = M.formatDataList([response.data], true);
            var $html = $(lib.template2(dataList, '#post_list_template'));
            if ($postList.length) {
                $html.insertBefore($postList.first());
            } else {
                $html.appendTo($('#post_list'));
            }
            // 绑定延迟加载图片事件
            $html && $html.find('img').lazyload();
            // 清除缓存，防止重复显示
            lib.removeSessionItem('latestQuestion');
        },
        generateQuestionStatus : function(post) {
            var html = '', status = post.status, tag = post.tag;
            if (status == 0) {
                if (tag && (parseInt(tag) & 2)) {
                    html = '<span class="icons">new</span>';
                }
            } else {
                html = '<span class="icons ico_close">已解决</span>';
            }
            return html;
        }
    };
    var C = {
        init : function() {
            $('#post_list').on(gc.click, 'li', function() {
                var $this = $(this);
                var questionId = $this.attr('questionId');
                lib.setParam('questionId', questionId);
                if (window.KalaGameUi && KalaGameUi.openFaqContentActivity) {
                    KalaGameUi.openFaqContentActivity('game-faq_content', "&" + lib.getAllParam());
                } else {
                    lib.redirectClient('game-faq_content');
                }
            });
            if (!window.KalaGame) {
                $("#game_subpost_wrapper").show();
            }
        }
    }
    // 初始化一次
    C.init();
    function init() {
        var gameId = lib.getParam('gameId');
        if (gameId != lastGameId) {
            $('#post_list').html('');
            // 显示loading
            $('#spinner_list').show();
            $('#loadingText').css('visibility', 'visible');
            M.getMyQuestionList();
            lastGameId = gameId;
        } else {
            var response = lib.getSessionItem('latestQuestion');
            if (response) {
                V.showLatestQuestion(response);
            } else {
                var listCount = $('#post_list li').length;
                M.getMyQuestionList(0, listCount);
            }
        }
        //绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#post_list'));
        // pull to refresh callback
        gc.pullToRefresh = exports.pullToRefresh;
    }
    


    function updateTime(serverTime) {
        var $postList = $('#post_list li');
        $postList.each(function() {
            var $this = $(this);
            var createTime = $this.attr('lastUpdateTime');
            if (serverTime && createTime) {
                var replyTime = lib.dateDiff(serverTime, createTime);
                $this.find('[postTime]').html(replyTime);
            }
        });
    }
});
