define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), com = require('gameComm'), lazyload = require('lazyload');
    exports.init = init;

    // 列表默认的显示数目
    var nDefaultCount = 10 * lib.listCountMultiples();

    var M = {
        getReplyDetail : function() {
            var strUrl = lib.bbsUrl + 'forum/getReplyDetail';
            var objData = {
                appId : lib.getParam('gameId'),
                postId : lib.getParam('postId'),
                boardId : lib.getParam('boardId'),
                replyId : lib.getParam('replyId')
            };

            // 显示真实数据前，显示“加载中...”
            V.showReplyDetailDefault();

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    V.showReplyDetail(objResult);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            }, {
                cache : true,
                noLoading : true
            });
        },
        formatData : function(objData, strServerTime) {
            if (!objData) {
                return;
            }

            // 设置头像
            var strIcon = objData.icon;
            objData.icon = strIcon ? strIcon : gc.defaultIcon_96;
            var strCreateTime = objData.createTime;
            if (strCreateTime) {
                objData.postTime = lib.dateDiff(strServerTime, objData.createTime);
            } else {
                objData.postTime = '加载中...';
            }

            // 解析表情
            var strContent = objData.content;
            var rPattern = /\[[\u4e00-\u9fa5]+\]/ig;

            if (strContent) {
                objData.content = strContent.replace(rPattern, com.parseEmotionPath);
            }

            // 解析图片
            var objAttach = objData.attach;
            if (objAttach) {
                var strHtml = com.parseUploadedImages(strContent, objAttach);
                objData.content += strHtml;
            }

            return objData;
        }
    };

    var V = {
        showReplyDetail : function(objResult) {
            var objData = M.formatData(objResult.data, objResult.serverTime);
            lib.template(objData, '#post_content');
            var $html = $('#post_content');

            if (!objResult.__default) {
                // 设置回复中图片的尺寸
                lib.setImgSize($html.find('p.comment'));
            }

            // 图片渐显
            $('#post_content img[data-original]').lazyload();
            $('#spinner_list').hide();
        },
        showReplyDetailDefault : function() {
            // 页面切换显示加载中
            var defaultData = {
                __default : true,
                objData : {
                    subject : '',
                    nickName : '',
                    content : '加载中...',
                }
            };

            // 去除已存在图片
            $('[name=icon]').removeAttr('src');
            V.showReplyDetail(defaultData);
        }
    };

    var C = {
        init : function() {
            C.bindShowOriginalImageEvent();
            // 绑定显示用户信息事件
            lib.bindShowUserInfoEvent('#post_content');
        },
        bindShowOriginalImageEvent : function() {
            $('#post_content').on(gc.click, 'p.comment img[data-original]', function() {
                var $this = $(this);
                var $content = $this.parent();

                // 设置当前点击图片的索引
                var nIndex = $content.find('img[data-original]').index($this);
                lib.showOriginalImg($content, nIndex);

                // 阻止事件冒泡
                return false;
            });
        }
    }

    // 初始化一次
    C.init();

    function init() {
        // 显示loading
        $('#spinner_list').show();
        $('#loadingText').css('visibility', 'visible');
        // 获取帖子详细信息
        M.getReplyDetail();
    }

});
