define(function(require, exports, module) {
    var $ = require('zepto'), lib = require('lib'), com = require('userCom');
    exports.init = init;

    // 默认平台ID，默认的重新发送等待时间
    var platformId = 1000, defaultResendTime = 60;
    var checkTimer, isImgVcode = false;

    var M = {
        sendRegisterCode : function() {
            var url = lib.userUrl + 'register/sendRegisterCode';
            var data = {
                platformId : platformId,
                uuid : window.device && device.uuid,
                isInit : 0,
                checkType : localStorage.getItem("checkType")
            };

            lib.postCross(url, data, function(objResult) {
                V.handleResponse(objResult);
            }, {
                noLoading : true
            });
        },
        completeRegister : function() {
            var data = lib.getSessionItem('registerInfo');
            var params = data && JSON.parse(data) || {};
            params.platformId = platformId;
            params.appId = lib.appId;
            params.registerType = 'normal';
            params.uuid = window.device && device.uuid;
            params['checkType'] = localStorage.getItem("checkType");

            lib.postCross(lib.userUrl + 'register/completeRegister', params, function(data) {
                data.token && localStorage.setItem('token', data.token);
                data.uid && localStorage.setItem('uid', data.uid);
                data.openId && lib.setOpenAuthInfo(lib.appId, 'openId', data.openId);
                data.openToken && lib.setOpenAuthInfo(lib.appId, 'openToken', data.openToken);

                if (data.result == 1) {
                    // 不存在openId，进入激活页面
                    if (lib.appId && lib.appId != 10000 && !data.openId) {
                        lib.redirect('user-activation');
                        return;
                    }

                    gc.reportAction("library", "completeRegister", 0, 'check_register');

                    localStorage.setItem('isOldUser', 1);
                    // 清除注册时保留的密码
                    localStorage.removeItem('pwd');
                    localStorage.removeItem('oldPwd');

                    if (window.KalaGame && KalaGame.session) {
                        KalaGame.session(data.uid, data.token, data.openId, data.openToken);
                    } else {
                        lib.redirect('user-info');
                    }

                    // 去除登录注册的特殊样式
                    lib.removeCustomizedStyle(lib.appId);
                } else {
                    lib.showTip(data.msg);
                }
            });
        },
        checkRegisterStatus : function() {
            var pwd = localStorage.getItem('pwd');
            var account = localStorage.getItem('account');
            var pattern = com.getPattern(platformId, account);
            var $submit = $('#submit'), $vcode = $('#inputVcode').parent();
            var $smsTip = $('#sms_tip'), $emailTip = $('#email_tip');
            var $msgTip = $('#msgTip'), $show_mail = $('#show_mail');

            if (account && pwd) {
                if (pattern == 2) {
                    $vcode.hide();
                    $smsTip.hide();
                    $emailTip.show();
                    $show_mail.show();
                    if (lib.getParam("channel") == "client") {
                        $submit.html('已完成激活 ');
                    } else {
                        $submit.html('已完成激活 开始游戏');
                    }
                    
                    $msgTip.html('一封激活邮件，请点击邮件中的激活链接完成注册');

                    // 打开相应邮箱
                    $('#show_mail a').attr('href', M.getEmailURL(account));
                } else if (pattern == 1) {
                    $vcode.show();
                    $smsTip.show();
                    $emailTip.hide();
                    $show_mail.hide();
                    
                    V.setSubmitText();

                    // 开启广播监听短信
                    window.KalaGame && KalaGame.registerSmsReceiver && KalaGame.registerSmsReceiver();
                }

                // 定时检查是否点击了激活链接
                lib.setInterval(M.checkStatus, 3000);
            }
        },
        checkStatus : function() {
            var url = lib.userUrl + 'register/checkRegisterStatus';
            var params = {
                token : localStorage.getItem('token'),
                checkType : localStorage.getItem("checkType")
            };

            lib.postCross(url, params, function(data) {
                if (data.result == 1 && data.valid) {
                    lib.redirect('user-activenotice');
                }
            }, {
                noLoading : true
            });
        },
        getEmailURL : function(email) {
            var emailURL = '';
            var emailHost = email.split("@")[1];
            switch (emailHost) {
                case 'qq.com':
                    emailURL = 'http://mail.qq.com';
                    break;
                case 'foxmail.com':
                    emailURL = 'http://mail.foxmail.com';
                    break;
                case '163.com':
                    emailURL = 'http://mail.163.com';
                    break;
                case '126.com':
                    emailURL = 'http://mail.126.com';
                    break;
                case 'yeah.net':
                    emailURL = 'http://mail.yeah.net';
                    break;
                case '139.com':
                    emailURL = 'http://mail.10086.cn';
                    break;
                case 'sohu.com':
                    emailURL = 'http://mail.sohu.com';
                    break;
                case 'sina.com':
                    emailURL = 'http://mail.sina.com.cn';
                    break;
                case 'yahoo.com.cn':
                case 'yahoo.cn':
                    emailURL = 'http://mail.cn.yahoo.com';
                    break;
                case 'gmail.com':
                    emailURL = 'https://mail.google.com';
                    break;
                case 'hotmail.com':
                    emailURL = 'http://mail.live.com';
                    break;
                case 'tom.com':
                    emailURL = 'http://mail.tom.com';
                    break;
                case '21cn.com':
                    emailURL = 'http://mail.21cn.com';
                    break;
                default:
                    emailURL = 'http://mail.' + emailHost;
                    break;
            }

            return emailURL;
        }
    };

    var V = {
        handleResponse : function(data, isInit) {
            C.freshTip(data.sendResult, data.lastTime);

            if (data.result == 1) {
                if (data.interval >= 0) {
                    lib.setSessionItem('resend', 0);
                    lib.setSessionItem('checkCount', data.interval);

                    C.check();
                    window.clearInterval(checkTimer);
                    checkTimer = lib.setInterval(C.check, 1000);
                }
            } else {
                if (data.ret == -6001) {
                    window.clearInterval(checkTimer);
                    lib.setSessionItem('checkCount', 0);
                    $('#resendMobile').val('发送激活码');
                    $('#resendMobile').removeClass('ontimer');

                    if (!isInit) {
                        lib.showVcode(function() {
                            isImgVcode = true;
                            M.sendRegisterCode();
                        });
                    }
                }
                lib.showTip(data.msg);
            }
        },
        resendMobile : function() {
            var checkCount = parseInt(lib.getSessionItem('checkCount')) || 0;
            if (checkCount > 0) {
                return false;
            }

            C.freshTip(1);
            V.doUpdateRegister();
            window.clearInterval(checkTimer);
            checkTimer = lib.setInterval(C.check, 1000);

            lib.setSessionItem('checkCount', defaultResendTime);
            var resend = parseInt(lib.getSessionItem('resend')) || 0;
            if (!resend) {
                return false;
            }
            M.sendRegisterCode();
        },
        subform : function() {
            var inputVcode = $.trim($('#inputVcode').val());
            if (!inputVcode) {
                lib.showTip('请输入激活码');
            } else if (inputVcode.length != 6) {
                lib.showTip('验证码格式错误，必须是6位数字。');
            } else {
                gc.checkRegister(inputVcode, true);
            }
        },
        doUpdateRegister : function() {
            var sendTip = '秒后可重新发送';
            var sendBtn = '点击重新发送';
            var checkCount = parseInt(lib.getSessionItem('checkCount')) || 0;
            var text = checkCount + sendTip;
            if (checkCount <= 0) {
                lib.setSessionItem('resend', 1);

                $('#resendMobile').val(sendBtn);
                $('#resendMobile').removeClass('ontimer');
            } else {
                $('#resendMobile').val(text);
                $('#resendMobile').addClass('ontimer');
            }
        },
        setSubmitText : function() {
            var $submit = $("#submit");
            if (lib.getParam("channel") == "client") {
                $submit.html('激活并进入');
            } else {
                $submit.html('激活并进入游戏');
            }
        }
    };

    var C = {
        init : function() {
            $('#resendMobile').on(gc.click, function() {
                V.resendMobile();
            });

            $('#submit').on(gc.click, function() {
                var account = localStorage.getItem('account');
                var pattern = com.getPattern(platformId, account);

                if (pattern == 1) {
                    V.subform();
                } else if (pattern == 2) {
                    M.completeRegister();
                }
            });

            $('.btn_back').on(gc.click, function() {
                window.clearInterval(checkTimer);
            });
        },
        initAccount : function() {
            var account = localStorage.getItem('account');
            if (account) {
                $('#account').val(account);
            } else {
                account = $('#account').val();
                localStorage.setItem('account', account);
            }

            gc.pattern = com.getPattern(platformId, account);
            $('.mobile').html(account);
            if (gc.pattern == 1) {
                $('#content1').html("一条激活短信");
                $('#content2').html("手机");
            } else {
                $('#content1').html("一封激活邮件");
                $('#content2').html("邮箱");
            }
        },
        pageInit : function() {
            lib.setSessionItem('resend', 0);
            V.setSubmitText();

            // 处理邀请码
            var registerCodeResponse = lib.getSessionItem('registerCodeResponse');
            var response = JSON.parse(registerCodeResponse);
            if (response) {
                V.handleResponse(response, true);
                // 清除缓存数据
                lib.removeSessionItem('registerCodeResponse');
            } else {
                // 从验证码页面跳转，则不发送
                if (isImgVcode) {
                    isImgVcode = false;
                    return;
                }
                M.sendRegisterCode();
            }

            M.checkRegisterStatus();
        },
        check : function() {
            var checkCount = parseInt(lib.getSessionItem('checkCount')) || 0;
            lib.setSessionItem('checkCount', --checkCount);

            if (checkCount <= 0) {
                window.clearInterval(checkTimer);
            }
            V.doUpdateRegister();
        },
        freshTip : function(sendResult, lastTime) {
            if (sendResult == 2) {
                $('.msg').show();
                $('#sendedInfoTip').show();
                if ( typeof (lastTime) != 'undefined') {
                    $('#lastTime').html(com.makeTimeTip(lastTime));
                }
                $('#sendInfoTip').hide();
            } else if (sendResult == 1) {
                $('.msg').show();
                $('#sendedInfoTip').hide();
                $('#sendInfoTip').show();
            } else {
                $('.msg').show();
                $('#sendedInfoTip').hide();
                $('#sendInfoTip').hide();
            }
        },
        bindBackEvent : function() {
            // 回退时隐藏大图显示
            var historyCallback = gc.historyBack;
            gc.historyBack = function() {
                lib.confirm("确定要退出本次注册吗？", function(index) {
                    switch (index) {
                        case 1:
                            historyCallback();
                            gc.historyBack = historyCallback;
                            break;
                        case 2:
                            window.KalaGame && KalaGame.setIsBusy && KalaGame.setIsBusy(false);
                            break;
                    }
                });
            };
        }
    };

    // 初始化执行一次
    C.init();

    function init() {
		lib.loadCustomizedStyle();
        // 设置默认的重发时间
        lib.setSessionItem('checkCount', defaultResendTime);

        C.initAccount();
        C.pageInit();
        C.bindBackEvent();
    }

});

