define(function(require, exports, module) {
    var $ = require('zepto'), lib = require('lib');
    var strBindType = null;
    exports.userUrl = lib.userUrl;
    exports.getPattern = getPattern;
    exports.makeTimeTip = makeTimeTip;
    exports.defaultSign = '无签名 不游戏';
    exports.updateBaseInfo = updateBaseInfo;
    exports.toggleThirdpartyLogin = toggleThirdpartyLogin;
    exports.addThirdpartyLoginParams = addThirdpartyLoginParams;
    // 定义第三方授权回调
    gc.thirdpartyAuth = thirdpartyAuth;
    /*************************    项目相关的私有公共js ***********************/
    function getPattern(platformId, account) {
        if (platformId == 1001) {
            return 4;
        } else if (platformId == 1000) {
            var email_pattern = /^[a-zA-Z0-9_.]{1,50}@[a-zA-Z0-9-]{1,65}\.([a-zA-Z]{2,5}(\.[a-zA-Z]{2,3})?$)/;
            // var mobile_pattern = /^(13|14|15|18)[0-9]{9}$/;
            var mobile_pattern = /^1\d{10}$/;
            var kala_pattern = /^[1-9][0-9]{5,10}$/;
            if (email_pattern.test(account)) {
                return 2;
            } else if (mobile_pattern.test(account)) {
                return 1;
            } else {
                return 0;
            }
        }
        return 0;
    }

    function makeTimeTip(time) {
        var msg = '';
        if (time.day != undefined) {
            msg = time.day + '天';
        } else if (time.hour != undefined) {
            msg = time.hour + '小时';
        } else if (time.min != undefined) {
            msg = time.min + '分钟';
        } else {
            msg = '1分钟';
        }
        return msg;
    }

    // 更新个人信息
    function updateBaseInfo(objData, callback) {
        var strUrl = lib.userUrl + 'detail/updateBaseInfo';
        lib.postCross(strUrl, objData, function(objResult) {
            // 此处为保存信息之后的操作
            if (objResult.result == 1) {
                callback && callback(objResult);
                lib.showTip('更新成功！');
            } else if (objResult.ret == -6001) {
                //这里是要显示验证码的情况
                lib.showVcode(function() {
                    updateBaseInfo(objData);
                });
            } else {
                lib.showTip(objResult.msg);
            }
        });
    }

    function updateBaseInfo1(callback, objOption) {
        // 获取表单数据
        var objInfo, objData;
        var objFormData = objOption && objOption.formData;
        var isHistoryBack = objOption && objOption.historyBack;
        if (!objFormData) {
            objInfo = lib.getSessionItem('info');
            objData = objInfo && JSON.parse(objInfo);
        } else {
            objData = objFormData;
        }
        if (!objData) {
            return;
        }
        var strUrl = lib.userUrl + 'detail/updateBaseInfo';
        lib.postCross(strUrl, objData, function(objResult) {
            // 此处为保存信息之后的操作
            if (objResult.result == 1) {
                callback && callback();
                lib.showTip('更新成功！');
                // 回退页面
                if (isHistoryBack) {
                    gc.historyBack();
                }
            } else if (objResult.ret == -6001) {
                //这里是要显示验证码的情况
                lib.showVcode(function() {
                    updateBaseInfo(callback, objOption);
                }, function() {
                    if (isHistoryBack) {
                        // 清空存储的信息
                        lib.removeSessionItem('info');
                    }
                });
            } else {
                lib.showTip(objResult.msg);
            }
        });
    }

    function thirdpartyAuth(authType, thirdPartId, accessToken, type) {
        var strUrl = '', objData = {};
        // 参数
        objData.appId = lib.getParam('appId');
        objData.thirdPartId = thirdPartId;
        objData.accessToken = accessToken;
        objData.type = type;
        // API地址
        if (authType === 'login') {
            strUrl = lib.userUrl + 'account/thirdPartLogin';
            objData.uuid = window.device && device.uuid;
        } else {
            strUrl = lib.userUrl + 'account/bindThirdPart';
        }
        lib.showLoading();
        lib.postCross(strUrl, objData, function(objResult) {
            lib.hideLoading();
            if (objResult.result) {
                if (authType === 'login') {
                    // 已经绑定过账号，直接登录成功进入
                    objResult.token && localStorage.setItem('token', objResult.token);
                    objResult.uid && localStorage.setItem('uid', objResult.uid);
                    objResult.openId && lib.setOpenAuthInfo(lib.appId, 'openId', objResult.openId);
                    objResult.openToken && lib.setOpenAuthInfo(lib.appId, 'openToken', objResult.openToken);
                    KalaGame.session(objResult.openId, objResult.openToken);
                } else {
                    // 绑定账号成功
                    console.log('==================================gc.thirdpartyCallback: ' + gc.thirdpartyCallback);
                    gc.thirdpartyCallback && gc.thirdpartyCallback();
                }
            } else {
                if (authType === 'login' && objResult.ret == -2051) {
                    strBindType = type;
                    localStorage.setItem('nickName', objResult.nickName);
                    lib.redirect('user-complete_info');
                } else {
                    console.log('==================================bind account failed: ' + objResult.msg);
                    lib.showTip(objResult.msg);
                }
            }
        }, {
            noLoading : true,
            onTimeout : function() {
                lib.confirm('登录超时，请重试！', function(index) {
                    switch (index) {
                        case 1:
                            thirdpartyAuth(authType, thirdPartId, accessToken, type);
                            break;
                        case 2:
                            if (window.KalaGame) {
                                KalaGame.closeWebView();
                            } else {
                                historyBack();
                            }
                            break;
                    }
                }, '', '重试,取消');
            }
        });
    }

    function toggleThirdpartyLogin() {
        var $thirdparty = $('#thirdparty_login');
        if (!window.KalaGame) {
            $thirdparty.show();
            bindThirdpartyLoginEvent();
        } else {
            $thirdparty.hide();
        }
    }

    function bindThirdpartyLoginEvent() {
        // 绑定第三方登录事件
        $('#thirdparty_login').on(gc.click, 'li', function() {
            var $this = $(this);
            var strThirdparty = $this.attr('thirdparty');
            switch (strThirdparty) {
                case 'qq':
                    if (window.KalaGame && KalaGame.tencentAuthorize) {
                        console.log('=======================thirdparty login: ' + strThirdparty);
                        KalaGame.tencentAuthorize('login');
                    }
                    break;
                case 'sina':
                    if (window.KalaGame && KalaGame.sinaWeiboAuthorize) {
                        console.log('=======================thirdparty login: ' + strThirdparty);
                        KalaGame.sinaWeiboAuthorize('login');
                    }
                    break;
                default:
                    break;
            }
        });
    }

    function addThirdpartyLoginParams(objData, strPage) {
        var page = lib.getParam('page');
        if (page === strPage && strBindType) {
            if (strBindType === 'qq') {
                objData.extAction = 'bindQQ';
            } else if (strBindType === 'sina') {
                objData.extAction = 'bindSina';
            }
        }
        return objData;
    }
});

