define(function(require, exports, module) {
    var $ = require('zepto'), lib = require('lib'), com = require('userCom'), md5 = require('md5');
    exports.init = init;

    // 默认平台ID
    var platformId = 1000;

    var M = {
        register : function() {
            var account = $('#account').val();
            var nickName = $('#nickName').val();
            var pwd = md5.sha1($('#comple_info_pwd').val());

            localStorage.setItem('account', account);
            localStorage.setItem('oldPwd', $('#comple_info_pwd').val());
            localStorage.setItem('nickName', nickName);

            gc.pattern = com.getPattern(platformId, account);
            localStorage.setItem('pattern', gc.pattern);

            var page = lib.getParam("page");
            //客户端进来的注册当作为绑定帐号
            if (page == "user-complete_moreinfo" || lib.getParam("channel") == "client") {
                if (!gc.pattern) {
                    lib.showTip('手机/邮箱格式错误');
                    lib.addFocus($('#account'));
                    return false;
                }

                var url = lib.userUrl + 'register/bindAccount';
                localStorage.setItem('checkType', 'bind');
            } else {
                if (gc.pattern != 1) {
                    lib.showTip('手机格式错误');
                    lib.addFocus($('#account'));
                    return false;
                }

                var url = lib.userUrl + 'register/register';
                localStorage.setItem('checkType', 'register');
            }

            var req = {
                pwd : md5.sha1(pwd),
                account : account,
                nickName : nickName,
                platformId : platformId,
                regPattern : gc.pattern,
                appId : lib.getParam('appId'),
                uuid : window.device && device.uuid
            };

            lib.showLoading(15000);
            lib.postCross(url, req, function(data) {
                if (data.result == 1) {
                    //注册成功了才保存密码
                    localStorage.setItem('pwd', pwd);

                    //有可能是无验证的方式
                    if (data.token && data.uid) {
                        data.token && localStorage.setItem('token', data.token);
                        data.uid && localStorage.setItem('uid', data.uid);
                        data.openId && lib.setOpenAuthInfo(lib.appId, 'openId', data.openId);
                        data.openToken && lib.setOpenAuthInfo(lib.appId, 'openToken', data.openToken);

                        // 不存在openId，进入激活页面
                        if (lib.appId && lib.appId != 10000 && !data.openId) {
                            lib.redirect('user-activation');
                            return;
                        }

                        localStorage.setItem('isOldUser', 1);
                        // 清除注册时保留的密码
                        localStorage.removeItem('pwd');
                        localStorage.removeItem('oldPwd');

                        if (window.KalaGame && KalaGame.session) {
                            KalaGame.session(data.uid, data.token, data.openId, data.openToken);
                        } else {
                            lib.redirect('user-info');
                            // 去除登录注册的特殊样式
                            lib.removeCustomizedStyle(lib.appId);
                        }
                    } else {
                        //直接显示loading避免衔接不好
                        //lib.showLoading(15000);
                        //有验证的方式，需要发送验证码
                        M.sendRegisterCode();
                    }
                } else {
                    lib.hideLoading();
                    if (data.ret == -6001) {
                        // 这里是要显示验证码的情况
                        lib.showVcode(M.register);
                        lib.showTip(data.msg);
                    } else if (data.ret == -2031) {
                        //说明用户已经绑定成功了,直接进入游戏
                        lib.redirect('user-activenotice');
                    } else {
                        lib.showTip(data.msg);
                    }
                }
            }, {
                noLoading : true
            });

        },
        sendRegisterCode : function() {
            var url = lib.userUrl + 'register/sendRegisterCode';
            var data = {
                platformId : platformId,
                uuid : window.device && device.uuid,
                isInit : 1,
                checkType : localStorage.getItem("checkType")
            };

            console.log('sendRegisterCode data:' + JSON.stringify(data));
            lib.postCross(url, data, function(response) {
                lib.setSessionItem('registerCodeResponse', JSON.stringify(response));
                lib.redirect('user-check_register');
            });
        }
    };

    var V = {
        checkPassword : function(password) {
            if (!password.length) {
                return false;
            }

            for (var i = 0; i < password.length; i++) {
                var chr = password.charCodeAt(i);
                if (chr > 255) {
                    lib.showTip('密码格式错误!');
                    return false;
                } else if (chr == 32) {
                    lib.showTip('密码不能包含空格符!');
                    return false;
                }
            }
            return true;
        }
    };

    var C = {
        init : function() {
            C.showPassword();
            $('#submitCompleteInfo').on(gc.click, function() {
                C.submitCompleteInfo();
            });

            C.initInput();
            //说明上次注册过，但可能没发送成功
            if (localStorage.pwd) {
                C.submitCompleteInfo();
            }

            $("#version").text(lib.getParam("channel") + " " + lib.getVersionString());
            $("#version").click(function() {
                $(this).css('opacity', '100');
            });
        },
        initInput : function() {
            //异步读取手机号码
            if (lib.getParam('channel') !== 'xiaomi') {
                setTimeout(function() {
                    var account = $('#account').val();
                    if (!account && window.KalaGame) {
                        KalaGame.getTelNum();
                    }
                }, 10);
            }

            localStorage.nickName && $('#nickName').val(localStorage.nickName);
            localStorage.oldPwd && $('#comple_info_pwd').val(localStorage.oldPwd);
        },
        submitCompleteInfo : function() {
            // 绑定表单验证事件
            var data = lib.getFormData($('#complete_info'));
            if (!data) {
                return;
            }

            var pwd = $("#comple_info_pwd").val();
            if (!V.checkPassword(pwd)) {
                return;
            }

            var $nickName = $('#nickName');
            var nickName = $nickName.val();

            if (nickName) {
                pwd = md5.sha1(md5.sha1(pwd));

                // 保存昵称和密码
                var registerInfo = {
                    nickName : nickName,
                    pwd : pwd
                };
                lib.setSessionItem('registerInfo', JSON.stringify(registerInfo));

                M.register();
            } else {
                lib.addFocus($nickName);
            }

            if (!localStorage.token) {
                lib.showTip('正在初始化中，请稍后再试.');
                lib.checkLogin();
                return false;
            }
        },
        showPassword : function() {
            $('#showpassword').on(gc.click, function() {
                var $this = $(this);
                var val = $this.html();
                var $password = $('#comple_info_pwd');

                if ($.trim(val) == '显示') {
                    $this.html('隐藏');
                    $password.attr('type', 'text');
                } else {
                    $this.html('显示');
                    $password.attr('type', 'password');
                }
            });
        }
    };

    gc.getTelNum = function(telNum) {
        if (telNum && telNum != 'null') {
            $('#account').val(telNum);
        }
    };

    // 初始化执行一次
    C.init();

    function init() {
        lib.loadCustomizedStyle();

        // 去除错误提示
        $('#complete_info input').removeClass('hover');
        
        //客户端运行邮箱输入
        if ( lib.getParam("channel") == "client") {
            $("#account").attr("type", "mail");
        }
    }

});
