define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload');
    exports.init = init;
    // 默认显示的游戏个数
    var defaultGameCount = 10 * lib.listCountMultiples();
    var M = {
        getFriendInfo     : function() {
            lib.postCross(lib.userUrl + 'friend/showInfo', {
                friendId : lib.getParam('friendId')
            }, function(getData) {
                if (getData.result == 1) {
                    V.showFriendInfo(getData.data);
                } else {
                    // 失败，直接退回登录页面
                    lib.redirect("user-login");
                }
            }, {
                cache : true
            });
        },
        getFriendGameList : function(start) {
            var url = lib.gameUrl + 'achievement/getFriendAppAchievement';
            var params = {
                start    : start || 0,
                friendId : lib.getParam('friendId'),
                count    : defaultGameCount
            }
            lib.postCrossList(url, params, function(responseData) {
                if (responseData.result == 1) {
                    V.showFriendGameList(responseData, start);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(responseData.msg);
                }
            }, function() {
                M.getFriendGameList(start);
            });
        },
        loadMore          : function() {
            var $gameList = $('#gameachivelist_wrap');
            var $spinner = $('#spinner_list');
            if ($gameList.attr('hasMore') != 'true') {
                $spinner.hide();
                return;
            }
            // 延迟显示
            var timeout = parseInt($spinner.attr('timeout'));
            lib.setTimeout(function() {
                var start = $gameList.find('li').length;
                M.getFriendGameList(start);
            }, timeout);
        },
        formatDataList    : function(dataList) {
            for (var i = 0, len = dataList.length; i < len; i++) {
                var app = dataList[i];
                var myAchievementPoint = app.myAchievementPoint;
                var achievementPoint = app.achievementPoint;
                if (achievementPoint && achievementPoint == -1) {
                    // 添加noAchieve属性，标识是否有成就系统
                    app.noachieve = 'noachieve';
                } else {
                    app.noachieve = '';
                }
                if (myAchievementPoint && myAchievementPoint == -1) {
                    app.myAchievementPoint = '-';
                }
            }
            return dataList;
        }
    };
    var V = {
        showFriendInfo     : function(data) {
            var sexIcon = $("#sex");
            if (data.sex == '1') {
                sexIcon.addClass('m');
            } else if (data.sex == '0') {
                sexIcon.removeAttr('class');
            }
            // 设置页面标题
            lib.setTitle(data.nickName);
            // 设置总的游戏数
            $('#gameachivelist_wrap h4 span').text(data.appCount);
            lib.template(data, '#friendinfo');
        },
        showFriendGameList : function(responseData, start) {
            var $gameList = $('#gameachivelist_wrap ul');
            var dataList = M.formatDataList(responseData.list);
            if (dataList.length) {
                // 如为页面初始化，则清空html
                !start && $gameList.html('');
                //显示缓存数据
                var $html = lib.showCacheList2(responseData, '#game_list_template', '#gameachivelist_wrap ul');
                // 绑定延迟加载图片事件
                $html && $html.find('img').lazyload();
            }
        }
    };
    var C = {
        init : function() {
            // 绑定显示详细成就事件
            $('#gameachivelist_wrap').on(gc.tap, 'li', function() {
                var $this = $(this);
                // 如果没有成就系统，不绑定显示事件
                if ($this.find('p.noachieve').length) {
                    return;
                }
                lib.redirect('achievement-compared');
            });
        }
    };
    // 初始化执行一次
    C.init();
    function init() {
        M.getFriendInfo();
        M.getFriendGameList();
        //绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#gameachivelist_wrap ul'));
    }
});
