define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload'), com = require('gameComm');

    exports.init = init;

    // 列表默认的显示数目
    var nDefaultCount = 10 * lib.listCountMultiples();
    // 当前点击的消息
    var $currentMsg = null, strServerTime = null;

    var M = {
        'retrieveMsgList' : function(strMsgId, isPullToRefresh) {
            var strUrl = lib.bbsUrl + 'forum/getMessages';

            var objData = {};
            objData.count = nDefaultCount;
            objData.lastMsgId = strMsgId || 0;

            // 客户端不添加appId信息，默认获取全部信息
            if (lib.getParam('channel') !== 'client') {
                objData.appId = lib.getParam('gameId');
            }

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    strServerTime = objResult.serverTime;
                    V.showMsgList(objResult, objData.lastMsgId);
                } else {
                    lib.showTip(objResult.msg);
                }

                // 客户端关闭刷新
                if (isPullToRefresh && window.KalaGameUi && KalaGameUi.closeRefresh) {
                    KalaGameUi.closeRefresh();
                }
            });
        },
        'prohibitReplyReminder' : function(objData) {
            var strMsgType = objData.msgType;
            var strUrl = lib.bbsUrl + 'forum/setPostRemind';
            if (strMsgType == 3) {
                strUrl = lib.bbsUrl + 'forum/setRelatedRemind';
            }
            delete objData.msgType;

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    $currentMsg.attr('noRemind', objData.isRemind);
                    lib.showTip('操作成功');
                } else {
                    lib.showTip(objResult.msg);
                }
            });
        },
        'checkPostStatus' : function(objData, callback) {
            var strUrl = lib.bbsUrl + 'forum/getPostDetail';

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    callback && callback();
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            });
        },
        'markMsgAsRead' : function(strMsgId) {
            var strUrl = lib.bbsUrl + 'forum/setMessageStatusRead';
            var objData = {};
            objData.msgId = strMsgId;

            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    // TODO : do sth.
                    console.log('marked message ' + strMsgId + ' as read successfully!');
                } else {
                    // 失败，显示提示信息
                    lib.showTip(objResult.msg);
                }
            });
        },
        'formatDataList' : function(arrDataList) {
            if (!arrDataList) {
                return;
            }

            for (var i = 0, nLen = arrDataList.length; i < nLen; i++) {
                var obj = arrDataList[i];

                // 设置extraInfo
                var objExtInfo = obj.extInfo;
                for (var key in objExtInfo) {
                    obj[key] = objExtInfo[key];
                }
                // 格式化消息数目，99+
                var nCount = obj.count;
                if (nCount > 99) {
                    nCount = '...';
                }
                obj.nCount = nCount;
                // 设置消息是否已读样式
                var strUnread = obj.unread;
                obj.unread = '';
                if (strUnread && strUnread == 1) {
                    obj.unread = 'unread';
                }
                // 格式化头像列表
                var arrList = [];
                var arrIcons = obj.icons;
                for (var j = 0, nIcons = arrIcons.length; j < nIcons; j++) {
                    var strIcon = arrIcons[j];

                    // 设置图标
                    if (strIcon) {
                        // 多个头像才使用小头像
                        if (nIcons > 1) {
                            strIcon = strIcon.replace(/\.thumb\./, '.tiny.');
                        }
                    } else {
                        strIcon = gc.defaultIcon_72;
                    }
                    arrList.push({
                        icon : strIcon
                    });
                }

                obj.iconList = lib.template2(arrList, '#icons_list_template');

                // 设置头像样式，回复人数
                var strStyle = '', strAndSoOn = '';
                var isMultiUser = obj.isMultiUser;
                if (isMultiUser) {
                    strAndSoOn = '等人';
                }

                if (nIcons == 2) {
                    strStyle = 'photo2';
                } else if (nIcons > 2) {
                    strStyle = 'photo4';
                }

                obj.andSoOn = strAndSoOn;
                obj.headClass = strStyle;

                // 格式化时间格式
                obj.lastUpdated = lib.dateDiff(strServerTime, obj.msgTime);

                // 解析表情
                var rPattern = /\[[\u4e00-\u9fa5]+\]/ig;
                var strContent = obj.msgBody;
                if (strContent) {
                    strContent = strContent.replace(rPattern, com.parseEmotionPath);
                }
                obj.parsedMsgBody = strContent;

                // 设置消息类型
                var nType = obj.msgType;
                var strMsgTypeStyle = 'msg_data clear', strMsgTypeContent = '';
                switch(nType) {
                    case '0':
                        strMsgTypeStyle = 'msg_system';
                        strMsgTypeContent = '系统消息';
                        break;
                    case '1':
                        obj.replyType = '我的主题';
                        strMsgTypeContent = lib.template2([obj], '#msg_type_template');
                        break;
                    case '2':
                        obj.replyType = '我的回帖';
                        strMsgTypeContent = lib.template2([obj], '#msg_type_template');
                        break;
                    case '3':
                        obj.replyType = '我参与的主题';
                        strMsgTypeContent = lib.template2([obj], '#msg_type_template');
                        break;
                    default:
                        break;
                }

                obj.msgTypeStyle = strMsgTypeStyle;
                obj.msgTypeContent = strMsgTypeContent;

                // 设置管理按钮 - 只PC可用
                var strCtrMenu = '';
                if (!window.KalaGameUi && nType != 0) {
                    strCtrMenu = '<span class="btn btn_normal">管理</span>';
                }
                obj.ctrMenu = strCtrMenu;
            }

            return arrDataList;
        },
        'loadMore' : function() {
            var $msgList = $('#msg_list');
            var $spinner = $('#spinner_list');
            if ($msgList.attr('hasMore') != 'true') {
                $spinner.hide();
                return;
            }

            var $lastMsg = $msgList.find('li').last();
            var strMsgId = $lastMsg.attr('msgId');
            M.retrieveMsgList(strMsgId);
        }
    };
    var V = {
        'showMsgList' : function(objResult, strLastMsgId) {
            var $nomsgbox = $('#nomsgbox');
            var arrDataList = M.formatDataList(objResult.list);

            // 清空
            !strLastMsgId && $('#msg_list').html('');

            // 显示列表
            if (arrDataList.length) {
                $nomsgbox.addClass('invisible');
                lib.showCacheList2(objResult, '#msg_list_template', '#msg_list');
            } else {
                $nomsgbox.removeClass('invisible');
                $('#spinner_list').hide();
            }

        },
        'showOptMenu' : function($this) {
            var strType = $this.attr('msgType');
            var strNoRemind = $this.attr('noRemind');
            var objOptions = {};
            if (strType == 1) {
                objOptions['data'] = [{
                    text : strNoRemind === '0' ? '禁止此贴提醒' : '恢复此贴提醒',
                    name : 1
                }];

                // 单个回复，显示查看详情
                var $icons = $this.find('[userCount]');
                var strCount = $icons.attr('userCount');
                if (strCount == 1) {
                    objOptions['data'] = [{
                        text : strNoRemind === '0' ? '禁止此贴提醒' : '恢复此贴提醒',
                        name : 1
                    }, {
                        text : '查看详情',
                        name : 2
                    }];
                }
            } else if (strType == 2) {
                objOptions['data'] = [{
                    text : strNoRemind === '0' ? '禁止此贴提醒' : '恢复此贴提醒',
                    name : 1
                }, {
                    text : '查看详情',
                    name : 2
                }];
            } else {
                objOptions['data'] = [{
                    text : strNoRemind === '0' ? '禁止此贴提醒' : '恢复此贴提醒',
                    name : 1
                }];
            }
            objOptions['callback'] = function(nName) {
                switch (nName) {
                    case 1:
                        // 禁止此贴回复提醒
                        var objData = {};
                        objData.msgType = strType;
                        // 主题和回复参数
                        objData.msgId = $this.attr('msgId');
                        objData.postId = $this.attr('postId');
                        objData.isRemind = strNoRemind === '0' ? 1 : 0;
                        // 我参与的主题
                        if (strType != 3) {
                            objData.appId = lib.getParam('gameId');
                            objData.boardId = $this.attr('boardId');
                            objData.replyId = $this.attr('replyId');
                            objData.parentId = $this.attr('parentId');
                        } else {
                            // 上报回复我参与的帖子禁止数
                            gc.reportAction('user-message', 'isRemind_click', 0, objData.isRemind);
                        }

                        M.prohibitReplyReminder(objData);
                        break;
                    case 2:
                        // 上报查看详情
                        gc.reportAction('user-message', 'msg_detail_click', 0, '');
                        // 查看消息详情
                        V.showMsgDetail($this, {
                            isReverse : false,
                            isClickMsg : false
                        });
                        break;
                    default:
                        $('#_menu').hide();
                        break;
                }
            };
            if (window.KalaGameUi && KalaGameUi.showSelectDialog) {
                KalaGameUi.showSelectDialog(objOptions);
            } else {
                lib.showOptMenu(objOptions);
            }
        },
        'showMsgDetail' : function($this, objOption) {
            // 消息详细页面
            var strPage = 'game-bbscontent';
            var isReverse = objOption.isReverse;
            var isClickMsg = objOption.isClickMsg;
            var strMsgType = $this.attr('msgType');
            if (strMsgType == 0) {
                strPage = 'user-system_msg_info';
                var objMsgInfo = {
                    data : {},
                    serverTime : strServerTime
                };

                objMsgInfo.data.icon = $this.find('.msg_headimg img').attr('src');
                objMsgInfo.data.subject = $('[msgTitle]').attr('msgTitle');
                objMsgInfo.data.content = $('[msgBody]').attr('msgBody');
                objMsgInfo.data.nickName = $('[nickName]').attr('nickName');
                objMsgInfo.data.createTime = $('[msgTime]').attr('msgTime');

                lib.setSessionItem('msgInfo', JSON.stringify(objMsgInfo));
            } else {
                if (!isClickMsg) {
                    // 设置replyId
                    lib.setParam('replyId', $this.attr('replyId'));
                    if (strMsgType == 1) {
                        strPage = 'game-reply_detail';
                    } else if (strMsgType == 2) {
                        strPage = 'game-bbsreply';
                        // 设置replyId为parentId
                        lib.setParam('replyId', $this.attr('parentId'));
                    }
                }

                // 倒序设置
                isReverse && lib.setSessionItem('isReverse', 1);
                lib.setParam('postId', $this.attr('postId'));
                lib.setParam('boardId', $this.attr('boardId'));
                lib.setSessionItem('lz', $this.attr('author'));
            }

            if (window.KalaGameUi) {
                if (strPage === 'game-bbscontent') {
                    KalaGameUi.openBbsContentActivity && KalaGameUi.openBbsContentActivity(strPage, '&' + lib.getAllParam());
                } else {
                    KalaGameUi.openActivity && KalaGameUi.openActivity(strPage, '&' + lib.getAllParam());
                }
            } else {
                lib.redirect(strPage);
            }

            // 标记消息已读
            var strMsgId = $this.attr('msgId') || $currentMsg.attr('msgId');
            M.markMsgAsRead(strMsgId);
        }
    };
    var C = {
        'init' : function() {
            C.bindShowOptMenuEvent();
            C.bindShowPostDetailEvent();
        },
        'bindShowOptMenuEvent' : function() {
            if (window.KalaGame) {
                $('#msg_list').on(gc.longTap, 'li', function() {
                    var $this = $(this);

                    $currentMsg = $this;
                    V.showOptMenu($currentMsg);
                });
            } else {
                $('#msg_list').on(gc.click, 'span.btn_normal', function() {
                    var $this = $(this);

                    $currentMsg = $this.parentsUntil('#msg_list').last();
                    V.showOptMenu($currentMsg);
                    return false;
                });
            }
        },
        'bindShowPostDetailEvent' : function() {
            $('#msg_list').on(gc.click, 'li', function() {
                var $this = $(this);
                var objData = {};
                objData.appId = $this.attr('appId');
                objData.postId = $this.attr('postId');
                objData.boardId = $this.attr('boardId');

                // 检查帖子是否存在
                M.checkPostStatus(objData, function() {
                    V.showMsgDetail($this, {
                        isReverse : true,
                        isClickMsg : true
                    });
                });
            });
        },
        'resetStuff' : function() {
            // 清除并隐藏消息列表
            $('#msg_list').addClass('invisible').html('');
            $('#spinner_list').show();
        }
    };

    // 初始化执行一次
    C.init();

    function init() {
        C.resetStuff();
        M.retrieveMsgList();

        // 绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#msg_list'));

        // pull to refresh callback
        gc.pullToRefresh = function() {
            M.retrieveMsgList(null, true);

            // 上报下拉刷新
            gc.reportAction(lib.getParam('page'), 'pullToRefresh', 0);
        }
        // 上报消息列表的访问次数
        gc.reportAction('user-message', 'view_msglist', 0, '');
    }

});
