define(function(require, exports, module) {
    var $ = require('zepto'), lib = require('lib'), com = require('user/js/common.js');
    exports.init = init;
    var M = {
        infoInit                   : function() {
            var strUrl = lib.userUrl + 'detail/getAccountInfo';
            lib.postCross(strUrl, function(objResult) {
                if (objResult.result == 1) {
                    V.showInfo(objResult);
                } else {
                    //失败，直接退回登录页面
                    lib.redirect("user-login");
                }
            }, {
                'cache' : true
            });
        },
        logout                     : function() {
            lib.confirm("确定要退出登录吗？", function(index) {
                if (index != 1) {
                    return;
                }
                var appId = lib.getParam('appId');
                var openId = lib.getOpenAuthInfo(appId, 'openId');
                var openToken = lib.getOpenAuthInfo(appId, 'openToken');
                var data = {};
                data['appId'] = appId;
                if (openId && openToken) {
                    data['openId'] = openId;
                    data['openToken'] = openToken;
                }
                var url = lib.userUrl + 'account/logout';
                lib.postCross(url, data, function(objResult) {
                    if (objResult.result) {
                        lib.logout();
                    } else {
                        lib.showTip(objResult.msg);
                    }
                });
            });
        },
        'getThirdpartyAccountInfo' : function() {
            var strUrl = lib.userUrl + 'detail/getThirdPartAccountInfo';
            lib.postCross(strUrl, function(objResult) {
                if (objResult.result == 1) {
                    V.showThirdpartyInfo(objResult);
                } else {
                    lib.showTip(objResult.msg);
                }
            }, {
                'cache' : true
            });
        },
        'unbindThirdparty'         : function(objData) {
            var strUrl = lib.userUrl + 'account/unbindThirdPart';
            lib.postCross(strUrl, objData, function(objResult) {
                if (objResult.result == 1) {
                    M.getThirdpartyAccountInfo();
                    lib.showTip('成功解除绑定');
                } else {
                    lib.showTip(objResult.msg);
                }
            });
        },
        'formatList'               : function(arrList) {
            if (!arrList.length) {
                return;
            }
            var obj, len = arrList.length;
            for (var i = 0; i < len; i++) {
                obj = arrList[i];
                var strId = obj.thirdPartId;
                var strNickName = obj.thirdPartNickName;
                if (strId) {
                    obj.isBind = 1;
                    obj.accountInfo = strNickName + ' <a href="javascript: void(0);">' + '(解除绑定)</a>';
                } else {
                    obj.isBind = 0;
                    obj.accountInfo = '未绑定';
                }
                var strAccountType = obj.accountType;
                switch (strAccountType) {
                    case '新浪微博':
                        obj.thirdparty = 'sina';
                        break;
                    case 'QQ':
                        obj.thirdparty = 'qq';
                        break;
                    default:
                        obj.thirdparty = '';
                        break;
                }
            }
            return arrList;
        },
        'formatData'               : function(objData) {
            if (!objData) {
                return;
            }
            // 设置默认签名
            if (!objData.sign) {
                objData.sign = com.defaultSign;
            }
            // 设置默认头像
            if (!objData.icon) {
                objData.icon = gc.defaultIcon_96;
            }
            return objData;
        }
    };
    var V = {
        showInfo             : function(objResult) {
            var objData = M.formatData(objResult.data);
            lib.template(objData, '#myaccount');
        },
        'showThirdpartyInfo' : function(objResult) {
            var arrList = M.formatList(objResult.list);
            if (arrList && arrList.length) {
                // 清除原有内容
                $('[isBind]').remove();
                var $html = $(lib.template2(arrList, '#thirdparty_info_template'));
                $html.appendTo('#settinglist');
            }
        }
    };
    var C = {
        init                   : function() {
            C.bindThirdpartyEvent();
            C.bindCheckUpdateEvent();
            $('#btn_logout').on("click", M.logout);
            //网页版和客户端版需要显示配置项
            if (!window.KalaGame || window.KalaGameClient) {
                $('.settinglist').show();
                $('#btn_logout').show();
            }
            $('#btn_recharge').on(gc.click, function() {
                if (lib.getParam("channel") == "xiaomi") {
                    lib.redirect("pay-mi_charge_combo");
                } else if (lib.getParam("channel") == "apple") {
                    lib.redirect("pay-ios_charge_combo");
                } else {
                    lib.redirect("pay-recharge");
                }
            });
        },
        'bindCheckUpdateEvent' : function() {
            var $checkUpdate = $('#checkUpdate');
            if (window.KalaGameClient && KalaGameClient.checkUpdate) {
                $checkUpdate.removeClass('invisible');
                $checkUpdate.on(gc.click, function() {
                    if (KalaGameClient.checkUpdate) {
                        KalaGameClient.checkUpdate();
                    } else {
                        lib.showTip('Web版本无需升级！');
                    }
                });
            } else {
                $checkUpdate.remove();
            }
        },
        'bindThirdpartyEvent'  : function() {
            $('#settinglist').on(gc.click, '[isBind]', function() {
                var $this = $(this);
                var isBind = ($this.attr('isBind') == '1') ? true : false;
                var strThirdparty = $this.attr('thirdparty');
                if (isBind) {
                    // 解除绑定
                    if (strThirdparty) {
                        lib.confirm('确定要解除绑定？', function(index) {
                            if (index != 1) {
                                return;
                            }
                            var objData = {};
                            objData.type = strThirdparty;
                            M.unbindThirdparty(objData);
                        });
                    }
                } else {
                    // 第三方登录
                    if (window.KalaGame) {
                        switch (strThirdparty) {
                            case 'qq':
                                if (KalaGame.tencentAuthorize) {
                                    console.log('=======================thirdparty bind account: ' + strThirdparty);
                                    KalaGame.tencentAuthorize('bindAccount');
                                }
                                break;
                            case 'sina':
                                if (KalaGame.sinaWeiboAuthorize) {
                                    console.log('=======================thirdparty bind account: ' + strThirdparty);
                                    KalaGame.sinaWeiboAuthorize('bindAccount');
                                }
                                break;
                            default:
                                break;
                        }
                    }
                }
            });
        }
    };

    function init() {
        M.infoInit();
        M.getThirdpartyAccountInfo();
    }

    C.init();
});

