define(function(require, exports, module) {
    var $ = require('jquery'), zepto = require('zepto'), lib = require('lib'), lazyload = require('lazyload');
    exports.init = init;
    exports.onStop = onStop;
    exports.updateTime = updateTime;

    // 列表默认的显示数目
    var defaultCount = 10 * lib.listCountMultiples();
    var currentPost, serverTime;

    var M = {
        getMyPostList : function(start, isPullToRefresh) {
            var url = lib.bbsUrl + 'forum/getMyPostList';
            var params = {
                appId : lib.getParam('gameId'),
                start : start || 0,
                count : defaultCount,
                category : 'post'
            }

            lib.postCrossList(url, params, function(response) {
                if (response.result == 1) {
                    // 保存服务端时间
                    serverTime = response.serverTime;
                    V.showMyPostList(response, start);
                } else {
                    // 失败，显示提示信息
                    lib.showTip(response.msg);
                }

                // 客户端关闭刷新
                if (isPullToRefresh && window.KalaGameUi && KalaGameUi.closeRefresh) {
                    KalaGameUi.closeRefresh();
                }
            }, function() {
                M.getMyPostList(start);
            }, false);
        },
        deletePost : function() {
            // 重要操作，提醒用户确认
            lib.confirm("确定要删除该贴？", function(index) {
                if (index != 1) {
                    return;
                }

                var strUrl = lib.bbsUrl + 'forum/deletePost';
                var objData = {};
                objData.appId = lib.getParam('gameId');
                objData.postId = currentPost.attr('postId');
                objData.boardId = currentPost.attr('boardId');

                lib.postCross(strUrl, objData, function(objResult) {
                    if (objResult.result == 1) {
                        // currentPost && currentPost.remove();
                        lib.showTip('操作成功！');
                        // 获取帖子列表
                        M.getMyPostList();
                    } else {
                        // 失败，显示提示信息
                        lib.showTip(objResult.msg);
                    }
                });
            });
        },
        formatDataList : function(dataList) {
            var len = dataList.length;
            if (!len) {
                return;
            }

            for (var i = 0; i < len; i++) {
                var post = dataList[i];

                post.postTime = lib.dateDiff(serverTime, post.createTime);
            }

            return dataList;
        },
        loadMore : function() {
            var $postList = $('#post_list');
            var start = $postList.find('li').length;
            M.getMyPostList(start);
        }
    };

    var V = {
        showMyPostList : function(response, start) {
            var $spinner = $('#spinner_list');
            var $postList = $('#post_list');
            var $noPosts = $('#no_posts');

            // 页面初始化时的操作
            !start && $postList.html('');

            // 格式化数据
            var dataList = M.formatDataList(response.list);

            if (dataList && dataList.length) {
                $postList.show();
                $noPosts.hide();

                // 显示缓存数据
                var $html = lib.showCacheList2(response, '#my_posts_template', $postList);
            } else {
                $postList.hide();
                $noPosts.show();
                $spinner.hide();
            }
        },
        showCtrMenu : function() {
            // 设置菜单显示内容及事件回调
            var option = {};
            option['title'] = '选择操作';
            // 设置用户菜单的显示
            option['data'] = [{
                text : '删除',
                name : 3
            }];
            option['callback'] = function(name) {
                switch (name) {
                    case 3:
                        M.deletePost();
                        break;
                    default:
                        $('#_menu').hide();
                        break;
                }
            };

            if (window.KalaGameUi && KalaGameUi.showSelectDialog) {
                KalaGameUi.showSelectDialog(option);
            } else {
                lib.showOptMenu(option);
            }
        }
    };

    var C = {
        init : function() {
            // 绑定帖子设置事件
            C.bindCtrMenuEvent();
            // 绑定显示帖子内容事件
            C.bindShowPostDetailEvent();

            // 管理菜单事件
            if (window.KalaGameUi && KalaGameUi.showReplyBtn) {
                $("#game_bbslist").css("padding-bottom", "0px");
            } else {
                $('#post_list').on(gc.click, 'p.btn_ctrl', function() {
                    var $this = $(this);
                    currentPost = $this.parent().parent();
                    V.showCtrMenu();
                    return false;
                });

                $('#game_subpost_box').show();
            }
        },
        bindShowPostDetailEvent : function() {
            $('#post_list').on(gc.click, 'li', function() {
                var $this = $(this);

                var postId = $this.attr('postId');
                var boardId = $this.attr('boardId');
                lib.setParam('postId', postId);
                lib.setParam('boardId', boardId);
                lib.setSessionItem('lz', $this.attr('author'));

                if (window.KalaGameUi && KalaGameUi.openBbsContentActivity) {
                    KalaGameUi.openBbsContentActivity("game-bbscontent", "&" + lib.getAllParam());
                } else {
                    lib.redirect('game-bbscontent');
                }
            });
        },
        bindCtrMenuEvent : function() {
            $('#post_list').on(gc.longTap, 'li', function() {
                var $this = $(this);
                var $ctrbtn = $this.find('p.btn_ctrl');

                if (window.KalaGame) {
                    currentPost = $this;
                    V.showCtrMenu();
                } else {
                    if (event.type == 'mouseout') {
                        $ctrbtn.hide();
                    } else {
                        $ctrbtn.show();
                    }
                }
            });

        }
    }

    // 初始化一次
    C.init();

    function init() {
        // 获取帖子列表
        M.getMyPostList();

        //绑定滚动条事件
        lib.bindScrollEvent(M.loadMore, $('#post_list'));

        // pull to refresh callback
        gc.pullToRefresh = function() {
            M.getMyPostList(0, true);

            // 上报下拉刷新
            gc.reportAction(lib.getParam('page'), 'pullToRefresh', 0);
        }
        // 点击顶部按钮回调
        gc.editBtnCallback = function(n) {
            if (n === 0) {
                lib.redirectClient('user-message');
            }
        }
    }

    function updateTime(serverTime) {
        var $postList = $('#post_list li');

        $postList.each(function() {
            var $this = $(this);
            var createTime = $this.attr('lastUpdateTime');

            if (serverTime && createTime) {
                var replyTime = lib.dateDiff(serverTime, createTime);

                $this.find('[postTime]').html(replyTime);
            }
        });
    }

    function onStop() {
        lib.clearTimer();
        console.log('=======leaving page: ' + lib.getParam('page') + ' & stop timer=======');
    }

});
